#!/bin/bash
gmt gmtset PS_MEDIA letter
gmt gmtset PROJ_LENGTH_UNIT cm
gmt gmtset FORMAT_GEO_MAP D
gmt gmtset PS_PAGE_ORIENTATION portrait
psfile=dezhgan5.11_base.ps
projection=-JM16.0c+
region=-R54.7/56.6/26.4/27.9
gmt psbasemap $region $projection -Bxa0.5f0.1 -Bya0.5f0.1 -BWeSn+t'Base Map dezhgan5.11' -K > $psfile

# Standard Topography (ETOPO1)
palette=-Ctables/gmt/cpt/topo.cpt
gmt grdcut @earth_relief_01m_g -Gmloc.grd $region
gmt grdgradient mloc.grd -Gmloc_ilum.grd -A340 -Nt
gmt grdimage mloc.grd $palette $projection -Imloc_ilum.grd -O -K >> $psfile
rm mloc.grd mloc_ilum.grd

# Coastlines and rivers
gmt pscoast $projection $region -Df -Ia/blue -Wblue -O -K >> $psfile

# Event numbers
gmt psxy -: -R $projection -Sl8p+t"1" -G0 -O -K << END >> $psfile
    27.024    55.532
END
gmt psxy -: -R $projection -Sl8p+t"2" -G0 -O -K << END >> $psfile
    27.046    55.608
END
gmt psxy -: -R $projection -Sl8p+t"3" -G0 -O -K << END >> $psfile
    27.066    55.573
END
gmt psxy -: -R $projection -Sl8p+t"4" -G0 -O -K << END >> $psfile
    27.034    55.540
END
gmt psxy -: -R $projection -Sl8p+t"5" -G0 -O -K << END >> $psfile
    27.315    55.032
END
gmt psxy -: -R $projection -Sl8p+t"6" -G0 -O -K << END >> $psfile
    27.057    55.488
END
gmt psxy -: -R $projection -Sl8p+t"7" -G0 -O -K << END >> $psfile
    27.111    55.350
END
gmt psxy -: -R $projection -Sl8p+t"8" -G0 -O -K << END >> $psfile
    27.109    55.372
END
gmt psxy -: -R $projection -Sl8p+t"9" -G0 -O -K << END >> $psfile
    27.072    55.482
END
gmt psxy -: -R $projection -Sl8p+t"10" -G0 -O -K << END >> $psfile
    27.842    54.950
END
gmt psxy -: -R $projection -Sl8p+t"11" -G0 -O -K << END >> $psfile
    27.301    54.971
END
gmt psxy -: -R $projection -Sl8p+t"12" -G0 -O -K << END >> $psfile
    27.386    56.144
END
gmt psxy -: -R $projection -Sl8p+t"13" -G0 -O -K << END >> $psfile
    27.131    55.423
END
gmt psxy -: -R $projection -Sl8p+t"14" -G0 -O -K << END >> $psfile
    27.120    55.441
END
gmt psxy -: -R $projection -Sl8p+t"15" -G0 -O -K << END >> $psfile
    27.160    55.948
END
gmt psxy -: -R $projection -Sl8p+t"16" -G0 -O -K << END >> $psfile
    26.875    55.787
END
gmt psxy -: -R $projection -Sl8p+t"17" -G0 -O -K << END >> $psfile
    26.733    54.981
END
gmt psxy -: -R $projection -Sl8p+t"18" -G0 -O -K << END >> $psfile
    26.705    54.909
END
gmt psxy -: -R $projection -Sl8p+t"19" -G0 -O -K << END >> $psfile
    26.975    56.222
END
gmt psxy -: -R $projection -Sl8p+t"20" -G0 -O -K << END >> $psfile
    26.770    55.049
END
gmt psxy -: -R $projection -Sl8p+t"21" -G0 -O -K << END >> $psfile
    27.430    56.197
END
gmt psxy -: -R $projection -Sl8p+t"22" -G0 -O -K << END >> $psfile
    26.796    55.981
END
gmt psxy -: -R $projection -Sl8p+t"23" -G0 -O -K << END >> $psfile
    27.374    55.850
END
gmt psxy -: -R $projection -Sl8p+t"24" -G0 -O -K << END >> $psfile
    27.315    54.983
END
gmt psxy -: -R $projection -Sl8p+t"25" -G0 -O -K << END >> $psfile
    26.968    54.910
END
gmt psxy -: -R $projection -Sl8p+t"26" -G0 -O -K << END >> $psfile
    27.388    56.174
END
gmt psxy -: -R $projection -Sl8p+t"27" -G0 -O -K << END >> $psfile
    26.930    54.882
END
gmt psxy -: -R $projection -Sl8p+t"28" -G0 -O -K << END >> $psfile
    27.053    55.641
END
gmt psxy -: -R $projection -Sl8p+t"29" -G0 -O -K << END >> $psfile
    26.659    55.897
END
gmt psxy -: -R $projection -Sl8p+t"30" -G0 -O -K << END >> $psfile
    27.414    56.208
END
gmt psxy -: -R $projection -Sl8p+t"31" -G0 -O -K << END >> $psfile
    27.292    56.111
END
gmt psxy -: -R $projection -Sl8p+t"32" -G0 -O -K << END >> $psfile
    27.082    56.079
END
gmt psxy -: -R $projection -Sl8p+t"33" -G0 -O -K << END >> $psfile
    26.837    55.896
END
gmt psxy -: -R $projection -Sl8p+t"34" -G0 -O -K << END >> $psfile
    26.851    55.873
END
gmt psxy -: -R $projection -Sl8p+t"35" -G0 -O -K << END >> $psfile
    26.797    55.865
END
gmt psxy -: -R $projection -Sl8p+t"36" -G0 -O -K << END >> $psfile
    26.825    55.894
END
gmt psxy -: -R $projection -Sl8p+t"37" -G0 -O -K << END >> $psfile
    26.804    55.931
END
gmt psxy -: -R $projection -Sl8p+t"38" -G0 -O -K << END >> $psfile
    26.847    55.859
END
gmt psxy -: -R $projection -Sl8p+t"39" -G0 -O -K << END >> $psfile
    26.895    55.839
END
gmt psxy -: -R $projection -Sl8p+t"40" -G0 -O -K << END >> $psfile
    26.830    55.898
END
gmt psxy -: -R $projection -Sl8p+t"41" -G0 -O -K << END >> $psfile
    26.816    55.887
END
gmt psxy -: -R $projection -Sl8p+t"42" -G0 -O -K << END >> $psfile
    26.835    55.904
END
gmt psxy -: -R $projection -Sl8p+t"43" -G0 -O -K << END >> $psfile
    26.814    55.867
END
gmt psxy -: -R $projection -Sl8p+t"44" -G0 -O -K << END >> $psfile
    26.809    55.903
END
gmt psxy -: -R $projection -Sl8p+t"45" -G0 -O -K << END >> $psfile
    26.836    55.791
END
gmt psxy -: -R $projection -Sl8p+t"46" -G0 -O -K << END >> $psfile
    26.809    55.903
END
gmt psxy -: -R $projection -Sl8p+t"47" -G0 -O -K << END >> $psfile
    26.798    55.900
END
gmt psxy -: -R $projection -Sl8p+t"48" -G0 -O -K << END >> $psfile
    26.861    55.982
END
gmt psxy -: -R $projection -Sl8p+t"49" -G0 -O -K << END >> $psfile
    26.823    55.885
END
gmt psxy -: -R $projection -Sl8p+t"50" -G0 -O -K << END >> $psfile
    26.901    55.917
END
gmt psxy -: -R $projection -Sl8p+t"51" -G0 -O -K << END >> $psfile
    26.852    55.959
END
gmt psxy -: -R $projection -Sl8p+t"52" -G0 -O -K << END >> $psfile
    26.823    55.918
END
gmt psxy -: -R $projection -Sl8p+t"53" -G0 -O -K << END >> $psfile
    26.864    55.963
END
gmt psxy -: -R $projection -Sl8p+t"54" -G0 -O -K << END >> $psfile
    26.898    55.933
END
gmt psxy -: -R $projection -Sl8p+t"55" -G0 -O -K << END >> $psfile
    26.847    55.970
END
gmt psxy -: -R $projection -Sl8p+t"56" -G0 -O -K << END >> $psfile
    26.837    55.976
END
gmt psxy -: -R $projection -Sl8p+t"57" -G0 -O -K << END >> $psfile
    26.864    55.964
END
gmt psxy -: -R $projection -Sl8p+t"58" -G0 -O -K << END >> $psfile
    26.874    55.951
END
gmt psxy -: -R $projection -Sl8p+t"59" -G0 -O -K << END >> $psfile
    26.820    55.965
END
gmt psxy -: -R $projection -Sl8p+t"60" -G0 -O -K << END >> $psfile
    26.838    55.942
END
gmt psxy -: -R $projection -Sl8p+t"61" -G0 -O -K << END >> $psfile
    26.819    55.940
END
gmt psxy -: -R $projection -Sl8p+t"62" -G0 -O -K << END >> $psfile
    26.822    55.909
END
gmt psxy -: -R $projection -Sl8p+t"63" -G0 -O -K << END >> $psfile
    26.833    55.852
END
gmt psxy -: -R $projection -Sl8p+t"64" -G0 -O -K << END >> $psfile
    26.853    55.929
END
gmt psxy -: -R $projection -Sl8p+t"65" -G0 -O -K << END >> $psfile
    26.823    55.887
END
gmt psxy -: -R $projection -Sl8p+t"66" -G0 -O -K << END >> $psfile
    26.851    55.961
END
gmt psxy -: -R $projection -Sl8p+t"67" -G0 -O -K << END >> $psfile
    26.821    55.960
END
gmt psxy -: -R $projection -Sl8p+t"68" -G0 -O -K << END >> $psfile
    27.341    54.959
END
gmt psxy -: -R $projection -Sl8p+t"69" -G0 -O -K << END >> $psfile
    26.886    55.920
END
gmt psxy -: -R $projection -Sl8p+t"70" -G0 -O -K << END >> $psfile
    26.820    55.898
END
gmt psxy -: -R $projection -Sl8p+t"71" -G0 -O -K << END >> $psfile
    26.908    55.741
END
gmt psxy -: -R $projection -Sl8p+t"72" -G0 -O -K << END >> $psfile
    27.503    55.492
END
gmt psxy -: -R $projection -Sl8p+t"73" -G0 -O -K << END >> $psfile
    27.480    55.385
END
gmt psxy -: -R $projection -Sl8p+t"74" -G0 -O -K << END >> $psfile
    26.824    55.941
END
gmt psxy -: -R $projection -Sl8p+t"75" -G0 -O -K << END >> $psfile
    26.825    55.889
END
gmt psxy -: -R $projection -Sl8p+t"76" -G0 -O -K << END >> $psfile
    27.745    55.403
END
gmt psxy -: -R $projection -Sl8p+t"77" -G0 -O -K << END >> $psfile
    27.736    55.433
END
gmt psxy -: -R $projection -Sl8p+t"78" -G0 -O -K << END >> $psfile
    27.372    54.946
END
gmt psxy -: -R $projection -Sl8p+t"79" -G0 -O -K << END >> $psfile
    26.826    55.944
END
gmt psxy -: -R $projection -Sl8p+t"80" -G0 -O -K << END >> $psfile
    26.831    55.935
END
gmt psxy -: -R $projection -Sl8p+t"81" -G0 -O -K << END >> $psfile
    26.850    55.969
END
gmt psxy -: -R $projection -Sl8p+t"82" -G0 -O -K << END >> $psfile
    26.894    55.967
END
gmt psxy -: -R $projection -Sl8p+t"83" -G0 -O -K << END >> $psfile
    26.911    55.889
END
gmt psxy -: -R $projection -Sl8p+t"84" -G0 -O -K << END >> $psfile
    26.932    55.877
END
gmt psxy -: -R $projection -Sl8p+t"85" -G0 -O -K << END >> $psfile
    26.945    55.941
END
gmt psxy -: -R $projection -Sl8p+t"86" -G0 -O -K << END >> $psfile
    26.899    55.892
END
gmt psxy -: -R $projection -Sl8p+t"87" -G0 -O -K << END >> $psfile
    26.874    55.871
END
gmt psxy -: -R $projection -Sl8p+t"88" -G0 -O -K << END >> $psfile
    26.844    55.922
END
gmt psxy -: -R $projection -Sl8p+t"89" -G0 -O -K << END >> $psfile
    26.910    55.938
END
gmt psxy -: -R $projection -Sl8p+t"90" -G0 -O -K << END >> $psfile
    26.928    55.898
END
gmt psxy -: -R $projection -Sl8p+t"91" -G0 -O -K << END >> $psfile
    26.933    55.919
END
gmt psxy -: -R $projection -Sl8p+t"92" -G0 -O -K << END >> $psfile
    26.973    55.923
END
gmt psxy -: -R $projection -Sl8p+t"93" -G0 -O -K << END >> $psfile
    26.893    55.892
END
gmt psxy -: -R $projection -Sl8p+t"94" -G0 -O -K << END >> $psfile
    26.917    55.939
END
gmt psxy -: -R $projection -Sl8p+t"95" -G0 -O -K << END >> $psfile
    26.941    55.935
END
gmt psxy -: -R $projection -Sl8p+t"96" -G0 -O -K << END >> $psfile
    26.871    55.886
END
gmt psxy -: -R $projection -Sl8p+t"97" -G0 -O -K << END >> $psfile
    26.868    55.843
END
gmt psxy -: -R $projection -Sl8p+t"98" -G0 -O -K << END >> $psfile
    26.850    55.906
END
gmt psxy -: -R $projection -Sl8p+t"99" -G0 -O -K << END >> $psfile
    27.587    55.294
END
gmt psxy -: -R $projection -Sl8p+t"100" -G0 -O -K << END >> $psfile
    27.731    55.158
END
gmt psxy -: -R $projection -Sl8p+t"101" -G0 -O -K << END >> $psfile
    26.934    55.926
END
gmt psxy -: -R $projection -Sl8p+t"102" -G0 -O -K << END >> $psfile
    27.603    55.289
END
gmt psxy -: -R $projection -Sl8p+t"103" -G0 -O -K << END >> $psfile
    26.890    55.914
END
gmt psxy -: -R $projection -Sl8p+t"104" -G0 -O -K << END >> $psfile
    26.901    55.941
END
gmt psxy -: -R $projection -Sl8p+t"105" -G0 -O -K << END >> $psfile
    26.918    55.905
END
gmt psxy -: -R $projection -Sl8p+t"106" -G0 -O -K << END >> $psfile
    26.780    55.830
END
gmt psxy -: -R $projection -Sl8p+t"107" -G0 -O -K << END >> $psfile
    27.605    55.262
END
gmt psxy -: -R $projection -Sl8p+t"108" -G0 -O -K << END >> $psfile
    27.014    54.971
END
gmt psxy -: -R $projection -Sl8p+t"109" -G0 -O -K << END >> $psfile
    27.604    55.406
END
gmt psxy -: -R $projection -Sl8p+t"110" -G0 -O -K << END >> $psfile
    27.615    55.450
END
gmt psxy -: -R $projection -Sl8p+t"111" -G0 -O -K << END >> $psfile
    26.877    56.335
END
gmt psxy -: -R $projection -Sl8p+t"112" -G0 -O -K << END >> $psfile
    26.842    55.340
END
gmt psxy -: -R $projection -Sl8p+t"113" -G0 -O -K << END >> $psfile
    26.875    56.291
END
gmt psxy -: -R $projection -Sl8p+t"114" -G0 -O -K << END >> $psfile
    27.417    56.006
END
gmt psxy -: -R $projection -Sl8p+t"115" -G0 -O -K << END >> $psfile
    27.374    55.986
END
gmt psxy -: -R $projection -Sl8p+t"116" -G0 -O -K << END >> $psfile
    27.749    55.041
END
gmt psxy -: -R $projection -Sl8p+t"117" -G0 -O -K << END >> $psfile
    27.343    55.981
END
gmt psxy -: -R $projection -Sl8p+t"118" -G0 -O -K << END >> $psfile
    27.814    55.236
END
gmt psxy -: -R $projection -Sl8p+t"119" -G0 -O -K << END >> $psfile
    26.860    55.898
END
gmt psxy -: -R $projection -Sl8p+t"120" -G0 -O -K << END >> $psfile
    26.851    55.892
END
gmt psxy -: -R $projection -Sl8p+t"121" -G0 -O -K << END >> $psfile
    26.886    55.896
END
gmt psxy -: -R $projection -Sl8p+t"122" -G0 -O -K << END >> $psfile
    26.908    55.867
END
gmt psxy -: -R $projection -Sl8p+t"123" -G0 -O -K << END >> $psfile
    26.852    55.898
END
gmt psxy -: -R $projection -Sl8p+t"124" -G0 -O -K << END >> $psfile
    26.947    55.858
END
gmt psxy -: -R $projection -Sl8p+t"125" -G0 -O -K << END >> $psfile
    26.912    55.936
END
gmt psxy -: -R $projection -Sl8p+t"126" -G0 -O -K << END >> $psfile
    26.856    55.845
END
gmt psxy -: -R $projection -Sl8p+t"127" -G0 -O -K << END >> $psfile
    26.851    55.876
END
gmt psxy -: -R $projection -Sl8p+t"128" -G0 -O -K << END >> $psfile
    26.872    55.946
END
gmt psxy -: -R $projection -Sl8p+t"129" -G0 -O -K << END >> $psfile
    26.904    55.925
END
gmt psxy -: -R $projection -Sl8p+t"130" -G0 -O -K << END >> $psfile
    26.868    55.855
END
gmt psxy -: -R $projection -Sl8p+t"131" -G0 -O -K << END >> $psfile
    26.875    55.859
END
gmt psxy -: -R $projection -Sl8p+t"132" -G0 -O -K << END >> $psfile
    26.865    55.854
END
gmt psxy -: -R $projection -Sl8p+t"133" -G0 -O -K << END >> $psfile
    26.867    55.899
END
gmt psxy -: -R $projection -Sl8p+t"134" -G0 -O -K << END >> $psfile
    26.946    56.079
END
gmt psxy -: -R $projection -Sl8p+t"135" -G0 -O -K << END >> $psfile
    26.975    56.127
END
gmt psxy -: -R $projection -Sl8p+t"136" -G0 -O -K << END >> $psfile
    26.991    56.116
END
gmt psxy -: -R $projection -Sl8p+t"137" -G0 -O -K << END >> $psfile
    26.993    56.104
END
gmt psxy -: -R $projection -Sl8p+t"138" -G0 -O -K << END >> $psfile
    26.982    56.084
END
gmt psxy -: -R $projection -Sl8p+t"139" -G0 -O -K << END >> $psfile
    27.004    56.112
END
gmt psxy -: -R $projection -Sl8p+t"140" -G0 -O -K << END >> $psfile
    26.885    56.173
END
gmt psxy -: -R $projection -Sl8p+t"141" -G0 -O -K << END >> $psfile
    26.978    56.070
END
gmt psxy -: -R $projection -Sl8p+t"142" -G0 -O -K << END >> $psfile
    26.944    55.863
END
gmt psxy -: -R $projection -Sl8p+t"143" -G0 -O -K << END >> $psfile
    26.936    56.016
END
gmt psxy -: -R $projection -Sl8p+t"144" -G0 -O -K << END >> $psfile
    26.957    56.175
END
gmt psxy -: -R $projection -Sl8p+t"145" -G0 -O -K << END >> $psfile
    26.899    55.915
END
gmt psxy -: -R $projection -Sl8p+t"146" -G0 -O -K << END >> $psfile
    27.381    56.026
END
gmt psxy -: -R $projection -Sl8p+t"147" -G0 -O -K << END >> $psfile
    26.972    56.168
END
gmt psxy -: -R $projection -Sl8p+t"148" -G0 -O -K << END >> $psfile
    26.970    56.102
END
gmt psxy -: -R $projection -Sl8p+t"149" -G0 -O -K << END >> $psfile
    26.982    56.143
END
gmt psxy -: -R $projection -Sl8p+t"150" -G0 -O -K << END >> $psfile
    26.971    56.124
END
gmt psxy -: -R $projection -Sl8p+t"151" -G0 -O -K << END >> $psfile
    26.968    56.134
END
gmt psxy -: -R $projection -Sl8p+t"152" -G0 -O -K << END >> $psfile
    26.954    56.120
END
gmt psxy -: -R $projection -Sl8p+t"153" -G0 -O -K << END >> $psfile
    27.435    56.161
END
gmt psxy -: -R $projection -Sl8p+t"154" -G0 -O -K << END >> $psfile
    26.808    55.896
END
gmt psxy -: -R $projection -Sl8p+t"155" -G0 -O -K << END >> $psfile
    26.679    55.126
END
gmt psxy -: -R $projection -Sl8p+t"156" -G0 -O -K << END >> $psfile
    26.919    55.943
END
gmt psxy -: -R $projection -Sl8p+t"157" -G0 -O -K << END >> $psfile
    26.779    55.037
END
gmt psxy -: -R $projection -Sl8p+t"158" -G0 -O -K << END >> $psfile
    26.701    55.042
END
gmt psxy -: -R $projection -Sl8p+t"159" -G0 -O -K << END >> $psfile
    26.725    55.086
END
gmt psxy -: -R $projection -Sl8p+t"160" -G0 -O -K << END >> $psfile
    26.678    55.121
END
gmt psxy -: -R $projection -Sl8p+t"161" -G0 -O -K << END >> $psfile
    26.853    55.863
END
gmt psxy -: -R $projection -Sl8p+t"162" -G0 -O -K << END >> $psfile
    26.621    55.061
END
gmt psxy -: -R $projection -Sl8p+t"163" -G0 -O -K << END >> $psfile
    26.897    55.918
END
gmt psxy -: -R $projection -Sl8p+t"164" -G0 -O -K << END >> $psfile
    26.961    55.941
END
gmt psxy -: -R $projection -Sl8p+t"165" -G0 -O -K << END >> $psfile
    26.958    55.925
END
gmt psxy -: -R $projection -Sl8p+t"166" -G0 -O -K << END >> $psfile
    26.961    55.948
END
gmt psxy -: -R $projection -Sl8p+t"167" -G0 -O -K << END >> $psfile
    26.942    55.930
END
gmt psxy -: -R $projection -Sl8p+t"168" -G0 -O -K << END >> $psfile
    27.006    55.931
END
gmt psxy -: -R $projection -Sl8p+t"169" -G0 -O -K << END >> $psfile
    26.878    55.905
END
gmt psxy -: -R $projection -Sl8p+t"170" -G0 -O -K << END >> $psfile
    26.960    56.045
END
gmt psxy -: -R $projection -Sl8p+t"171" -G0 -O -K << END >> $psfile
    26.927    56.003
END
gmt psxy -: -R $projection -Sl8p+t"172" -G0 -O -K << END >> $psfile
    27.589    55.498
END
gmt psxy -: -R $projection -Sl8p+t"173" -G0 -O -K << END >> $psfile
    27.160    55.851
END
gmt psxy -: -R $projection -Sl8p+t"174" -G0 -O -K << END >> $psfile
    26.929    55.935
END
gmt psxy -: -R $projection -Sl8p+t"175" -G0 -O -K << END >> $psfile
    26.814    55.827
END
gmt psxy -: -R $projection -Sl8p+t"176" -G0 -O -K << END >> $psfile
    26.801    55.806
END
gmt psxy -: -R $projection -Sl8p+t"177" -G0 -O -K << END >> $psfile
    26.791    55.855
END
gmt psxy -: -R $projection -Sl8p+t"178" -G0 -O -K << END >> $psfile
    26.794    55.849
END
gmt psxy -: -R $projection -Sl8p+t"179" -G0 -O -K << END >> $psfile
    27.196    56.116
END
gmt psxy -: -R $projection -Sl8p+t"180" -G0 -O -K << END >> $psfile
    27.247    56.222
END
gmt psxy -: -R $projection -Sl8p+t"181" -G0 -O -K << END >> $psfile
    27.231    56.266
END
gmt psxy -: -R $projection -Sl8p+t"182" -G0 -O -K << END >> $psfile
    26.957    56.059
END
gmt psxy -: -R $projection -Sl8p+t"183" -G0 -O -K << END >> $psfile
    27.609    55.239
END
gmt psxy -: -R $projection -Sl8p+t"184" -G0 -O -K << END >> $psfile
    27.187    55.604
END
gmt psxy -: -R $projection -Sl8p+t"185" -G0 -O -K << END >> $psfile
    27.198    55.609
END
gmt psxy -: -R $projection -Sl8p+t"186" -G0 -O -K << END >> $psfile
    27.221    55.018
END
gmt psxy -: -R $projection -Sl8p+t"187" -G0 -O -K << END >> $psfile
    27.212    54.949
END
gmt psxy -: -R $projection -Sl8p+t"188" -G0 -O -K << END >> $psfile
    27.188    54.921
END
gmt psxy -: -R $projection -Sl8p+t"189" -G0 -O -K << END >> $psfile
    27.406    56.170
END
gmt psxy -: -R $projection -Sl8p+t"190" -G0 -O -K << END >> $psfile
    26.952    55.712
END
gmt psxy -: -R $projection -Sl8p+t"191" -G0 -O -K << END >> $psfile
    27.064    55.666
END
gmt psxy -: -R $projection -Sl8p+t"192" -G0 -O -K << END >> $psfile
    27.519    55.356
END
gmt psxy -: -R $projection -Sl8p+t"193" -G0 -O -K << END >> $psfile
    27.334    55.977
END
gmt psxy -: -R $projection -Sl8p+t"194" -G0 -O -K << END >> $psfile
    26.873    55.944
END
gmt psxy -: -R $projection -Sl8p+t"195" -G0 -O -K << END >> $psfile
    27.318    56.478
END
gmt psxy -: -R $projection -Sl8p+t"196" -G0 -O -K << END >> $psfile
    27.378    55.669
END
gmt psxy -: -R $projection -Sl8p+t"197" -G0 -O -K << END >> $psfile
    26.677    55.453
END
gmt psxy -: -R $projection -Sl8p+t"198" -G0 -O -K << END >> $psfile
    27.751    55.017
END
gmt psxy -: -R $projection -Sl8p+t"199" -G0 -O -K << END >> $psfile
    26.691    55.342
END
gmt psxy -: -R $projection -Sl8p+t"200" -G0 -O -K << END >> $psfile
    26.899    55.862
END
gmt psxy -: -R $projection -Sl8p+t"201" -G0 -O -K << END >> $psfile
    26.690    55.098
END
gmt psxy -: -R $projection -Sl8p+t"202" -G0 -O -K << END >> $psfile
    27.095    55.709
END
gmt psxy -: -R $projection -Sl8p+t"203" -G0 -O -K << END >> $psfile
    27.176    54.830
END
gmt psxy -: -R $projection -Sl8p+t"204" -G0 -O -K << END >> $psfile
    27.153    54.884
END
gmt psxy -: -R $projection -Sl8p+t"205" -G0 -O -K << END >> $psfile
    26.975    55.109
END
gmt psxy -: -R $projection -Sl8p+t"206" -G0 -O -K << END >> $psfile
    27.277    55.646
END
gmt psxy -: -R $projection -Sl8p+t"207" -G0 -O -K << END >> $psfile
    27.103    56.267
END
gmt psxy -: -R $projection -Sl8p+t"208" -G0 -O -K << END >> $psfile
    26.912    56.119
END
gmt psxy -: -R $projection -Sl8p+t"209" -G0 -O -K << END >> $psfile
    27.031    55.080
END
gmt psxy -: -R $projection -Sl8p+t"210" -G0 -O -K << END >> $psfile
    27.039    56.220
END
gmt psxy -: -R $projection -Sl8p+t"211" -G0 -O -K << END >> $psfile
    26.789    55.269
END
gmt psxy -: -R $projection -Sl8p+t"212" -G0 -O -K << END >> $psfile
    27.310    55.020
END
gmt psxy -: -R $projection -Sl8p+t"213" -G0 -O -K << END >> $psfile
    27.254    55.017
END
gmt psxy -: -R $projection -Sl8p+t"214" -G0 -O -K << END >> $psfile
    27.311    54.994
END
gmt psxy -: -R $projection -Sl8p+t"215" -G0 -O -K << END >> $psfile
    27.326    55.006
END
gmt psxy -: -R $projection -Sl8p+t"216" -G0 -O -K << END >> $psfile
    27.238    55.003
END
gmt psxy -: -R $projection -Sl8p+t"217" -G0 -O -K << END >> $psfile
    27.317    55.019
END
gmt psxy -: -R $projection -Sl8p+t"218" -G0 -O -K << END >> $psfile
    27.322    55.020
END
gmt psxy -: -R $projection -Sl8p+t"219" -G0 -O -K << END >> $psfile
    26.927    54.959
END
gmt psxy -: -R $projection -Sl8p+t"220" -G0 -O -K << END >> $psfile
    27.250    55.876
END
gmt psxy -: -R $projection -Sl8p+t"221" -G0 -O -K << END >> $psfile
    26.952    54.913
END
gmt psxy -: -R $projection -Sl8p+t"222" -G0 -O -K << END >> $psfile
    26.739    55.096
END
gmt psxy -: -R $projection -Sl8p+t"223" -G0 -O -K << END >> $psfile
    26.581    55.859
END
gmt psxy -: -R $projection -Sl8p+t"224" -G0 -O -K << END >> $psfile
    26.890    55.400
END
gmt psxy -: -R $projection -Sl8p+t"225" -G0 -O -K << END >> $psfile
    26.916    55.964
END
gmt psxy -: -R $projection -Sl8p+t"226" -G0 -O -K << END >> $psfile
    26.898    54.895
END
gmt psxy -: -R $projection -Sl8p+t"227" -G0 -O -K << END >> $psfile
    26.861    55.932
END
gmt psxy -: -R $projection -Sl8p+t"228" -G0 -O -K << END >> $psfile
    26.853    55.945
END
gmt psxy -: -R $projection -Sl8p+t"229" -G0 -O -K << END >> $psfile
    27.318    54.867
END
gmt psxy -: -R $projection -Sl8p+t"230" -G0 -O -K << END >> $psfile
    27.213    55.184
END
gmt psxy -: -R $projection -Sl8p+t"231" -G0 -O -K << END >> $psfile
    26.566    55.318
END
gmt psxy -: -R $projection -Sl8p+t"232" -G0 -O -K << END >> $psfile
    27.289    55.766
END
gmt psxy -: -R $projection -Sl8p+t"233" -G0 -O -K << END >> $psfile
    27.246    55.961
END
gmt psxy -: -R $projection -Sl8p+t"234" -G0 -O -K << END >> $psfile
    27.243    54.973
END
gmt psxy -: -R $projection -Sl8p+t"235" -G0 -O -K << END >> $psfile
    27.226    55.022
END
gmt psxy -: -R $projection -Sl8p+t"236" -G0 -O -K << END >> $psfile
    26.788    54.898
END
gmt psxy -: -R $projection -Sl8p+t"237" -G0 -O -K << END >> $psfile
    26.806    54.924
END
gmt psxy -: -R $projection -Sl8p+t"238" -G0 -O -K << END >> $psfile
    26.571    55.869
END
gmt psxy -: -R $projection -Sl8p+t"239" -G0 -O -K << END >> $psfile
    27.735    55.053
END
gmt psxy -: -R $projection -Sl8p+t"240" -G0 -O -K << END >> $psfile
    27.015    55.164
END
gmt psxy -: -R $projection -Sl8p+t"241" -G0 -O -K << END >> $psfile
    27.162    55.116
END
gmt psxy -: -R $projection -Sl8p+t"242" -G0 -O -K << END >> $psfile
    27.177    55.138
END
gmt psxy -: -R $projection -Sl8p+t"243" -G0 -O -K << END >> $psfile
    26.548    55.222
END
gmt psxy -: -R $projection -Sl8p+t"244" -G0 -O -K << END >> $psfile
    26.640    55.471
END
gmt psxy -: -R $projection -Sl8p+t"245" -G0 -O -K << END >> $psfile
    26.517    55.048
END
gmt psxy -: -R $projection -Sl8p+t"246" -G0 -O -K << END >> $psfile
    27.308    54.907
END
gmt psxy -: -R $projection -Sl8p+t"247" -G0 -O -K << END >> $psfile
    27.203    55.141
END
gmt psxy -: -R $projection -Sl8p+t"248" -G0 -O -K << END >> $psfile
    26.987    54.940
END
gmt psxy -: -R $projection -Sl8p+t"249" -G0 -O -K << END >> $psfile
    26.967    54.926
END
gmt psxy -: -R $projection -Sl8p+t"250" -G0 -O -K << END >> $psfile
    26.517    55.850
END
gmt psxy -: -R $projection -Sl8p+t"251" -G0 -O -K << END >> $psfile
    26.509    55.763
END
gmt psxy -: -R $projection -Sl8p+t"252" -G0 -O -K << END >> $psfile
    27.095    56.069
END
gmt psxy -: -R $projection -Sl8p+t"253" -G0 -O -K << END >> $psfile
    26.478    55.671
END
gmt psxy -: -R $projection -Sl8p+t"254" -G0 -O -K << END >> $psfile
    26.464    55.713
END
gmt psxy -: -R $projection -Sl8p+t"255" -G0 -O -K << END >> $psfile
    27.110    56.060
END
gmt psxy -: -R $projection -Sl8p+t"256" -G0 -O -K << END >> $psfile
    26.940    54.897
END
gmt psxy -: -R $projection -Sl8p+t"257" -G0 -O -K << END >> $psfile
    26.646    55.512
END
gmt psxy -: -R $projection -Sl8p+t"258" -G0 -O -K << END >> $psfile
    26.842    55.384
END
gmt psxy -: -R $projection -Sl8p+t"259" -G0 -O -K << END >> $psfile
    27.345    56.145
END
gmt psxy -: -R $projection -Sl8p+t"260" -G0 -O -K << END >> $psfile
    27.358    54.915
END
gmt psxy -: -R $projection -Sl8p+t"261" -G0 -O -K << END >> $psfile
    27.739    55.192
END
gmt psxy -: -R $projection -Sl8p+t"262" -G0 -O -K << END >> $psfile
    27.620    55.382
END
gmt psxy -: -R $projection -Sl8p+t"263" -G0 -O -K << END >> $psfile
    26.868    55.982
END
gmt psxy -: -R $projection -Sl8p+t"264" -G0 -O -K << END >> $psfile
    26.985    54.873
END
gmt psxy -: -R $projection -Sl8p+t"265" -G0 -O -K << END >> $psfile
    26.931    55.972
END
gmt psxy -: -R $projection -Sl8p+t"266" -G0 -O -K << END >> $psfile
    26.608    55.718
END
gmt psxy -: -R $projection -Sl8p+t"267" -G0 -O -K << END >> $psfile
    27.406    56.194
END
gmt psxy -: -R $projection -Sl8p+t"268" -G0 -O -K << END >> $psfile
    26.817    55.226
END
gmt psxy -: -R $projection -Sl8p+t"269" -G0 -O -K << END >> $psfile
    26.545    56.419
END
gmt psxy -: -R $projection -Sl8p+t"270" -G0 -O -K << END >> $psfile
    27.397    56.399
END
gmt psxy -: -R $projection -Sl8p+t"271" -G0 -O -K << END >> $psfile
    26.719    55.619
END
gmt psxy -: -R $projection -Sl8p+t"272" -G0 -O -K << END >> $psfile
    26.922    55.905
END
gmt psxy -: -R $projection -Sl8p+t"273" -G0 -O -K << END >> $psfile
    27.046    55.154
END
gmt psxy -: -R $projection -Sl8p+t"274" -G0 -O -K << END >> $psfile
    27.145    56.008
END
gmt psxy -: -R $projection -Sl8p+t"275" -G0 -O -K << END >> $psfile
    27.597    54.962
END
gmt psxy -: -R $projection -Sl8p+t"276" -G0 -O -K << END >> $psfile
    27.623    54.944
END
gmt psxy -: -R $projection -Sl8p+t"277" -G0 -O -K << END >> $psfile
    27.598    54.983
END
gmt psxy -: -R $projection -Sl8p+t"278" -G0 -O -K << END >> $psfile
    27.594    55.006
END
gmt psxy -: -R $projection -Sl8p+t"279" -G0 -O -K << END >> $psfile
    27.614    54.954
END
gmt psxy -: -R $projection -Sl8p+t"280" -G0 -O -K << END >> $psfile
    27.622    54.986
END
gmt psxy -: -R $projection -Sl8p+t"281" -G0 -O -K << END >> $psfile
    27.078    55.142
END
gmt psxy -: -R $projection -Sl8p+t"282" -G0 -O -K << END >> $psfile
    27.613    54.996
END
gmt psxy -: -R $projection -Sl8p+t"283" -G0 -O -K << END >> $psfile
    27.224    56.256
END
gmt psxy -: -R $projection -Sl8p+t"284" -G0 -O -K << END >> $psfile
    27.706    54.945
END
gmt psxy -: -R $projection -Sl8p+t"285" -G0 -O -K << END >> $psfile
    27.392    56.274
END
gmt psxy -: -R $projection -Sl8p+t"286" -G0 -O -K << END >> $psfile
    26.906    55.817
END
gmt psxy -: -R $projection -Sl8p+t"287" -G0 -O -K << END >> $psfile
    27.170    55.852
END
gmt psxy -: -R $projection -Sl8p+t"288" -G0 -O -K << END >> $psfile
    27.046    55.692
END
gmt psxy -: -R $projection -Sl8p+t"289" -G0 -O -K << END >> $psfile
    27.037    55.679
END
gmt psxy -: -R $projection -Sl8p+t"290" -G0 -O -K << END >> $psfile
    26.972    55.712
END
gmt psxy -: -R $projection -Sl8p+t"291" -G0 -O -K << END >> $psfile
    27.043    55.688
END
gmt psxy -: -R $projection -Sl8p+t"292" -G0 -O -K << END >> $psfile
    27.013    55.143
END
gmt psxy -: -R $projection -Sl8p+t"293" -G0 -O -K << END >> $psfile
    27.082    55.275
END
gmt psxy -: -R $projection -Sl8p+t"294" -G0 -O -K << END >> $psfile
    27.150    55.879
END
gmt psxy -: -R $projection -Sl8p+t"295" -G0 -O -K << END >> $psfile
    26.839    55.358
END
gmt psxy -: -R $projection -Sl8p+t"296" -G0 -O -K << END >> $psfile
    27.031    55.680
END
gmt psxy -: -R $projection -Sl8p+t"297" -G0 -O -K << END >> $psfile
    26.864    55.376
END
gmt psxy -: -R $projection -Sl8p+t"298" -G0 -O -K << END >> $psfile
    27.180    54.896
END
gmt psxy -: -R $projection -Sl8p+t"299" -G0 -O -K << END >> $psfile
    26.710    55.150
END
gmt psxy -: -R $projection -Sl8p+t"300" -G0 -O -K << END >> $psfile
    26.710    55.102
END
gmt psxy -: -R $projection -Sl8p+t"301" -G0 -O -K << END >> $psfile
    26.728    55.122
END
gmt psxy -: -R $projection -Sl8p+t"302" -G0 -O -K << END >> $psfile
    26.691    55.128
END
gmt psxy -: -R $projection -Sl8p+t"303" -G0 -O -K << END >> $psfile
    26.596    55.474
END
gmt psxy -: -R $projection -Sl8p+t"304" -G0 -O -K << END >> $psfile
    26.695    56.260
END
gmt psxy -: -R $projection -Sl8p+t"305" -G0 -O -K << END >> $psfile
    26.927    55.703
END
gmt psxy -: -R $projection -Sl8p+t"306" -G0 -O -K << END >> $psfile
    26.940    55.697
END
gmt psxy -: -R $projection -Sl8p+t"307" -G0 -O -K << END >> $psfile
    26.929    55.697
END
gmt psxy -: -R $projection -Sl8p+t"308" -G0 -O -K << END >> $psfile
    26.936    55.689
END
gmt psxy -: -R $projection -Sl8p+t"309" -G0 -O -K << END >> $psfile
    27.214    54.850
END
gmt psxy -: -R $projection -Sl8p+t"310" -G0 -O -K << END >> $psfile
    26.675    55.287
END
gmt psxy -: -R $projection -Sl8p+t"311" -G0 -O -K << END >> $psfile
    26.658    55.269
END
gmt psxy -: -R $projection -Sl8p+t"312" -G0 -O -K << END >> $psfile
    27.199    55.153
END
gmt psxy -: -R $projection -Sl8p+t"313" -G0 -O -K << END >> $psfile
    27.192    55.089
END
gmt psxy -: -R $projection -Sl8p+t"314" -G0 -O -K << END >> $psfile
    27.232    55.071
END
gmt psxy -: -R $projection -Sl8p+t"315" -G0 -O -K << END >> $psfile
    27.189    55.106
END
gmt psxy -: -R $projection -Sl8p+t"316" -G0 -O -K << END >> $psfile
    27.221    55.071
END
gmt psxy -: -R $projection -Sl8p+t"317" -G0 -O -K << END >> $psfile
    27.222    55.069
END
gmt psxy -: -R $projection -Sl8p+t"318" -G0 -O -K << END >> $psfile
    27.196    55.106
END
gmt psxy -: -R $projection -Sl8p+t"319" -G0 -O -K << END >> $psfile
    27.195    55.113
END
gmt psxy -: -R $projection -Sl8p+t"320" -G0 -O -K << END >> $psfile
    27.180    55.141
END
gmt psxy -: -R $projection -Sl8p+t"321" -G0 -O -K << END >> $psfile
    27.209    55.088
END
gmt psxy -: -R $projection -Sl8p+t"322" -G0 -O -K << END >> $psfile
    26.665    55.261
END
gmt psxy -: -R $projection -Sl8p+t"323" -G0 -O -K << END >> $psfile
    27.179    55.096
END
gmt psxy -: -R $projection -Sl8p+t"324" -G0 -O -K << END >> $psfile
    27.201    55.082
END
gmt psxy -: -R $projection -Sl8p+t"325" -G0 -O -K << END >> $psfile
    27.185    55.087
END
gmt psxy -: -R $projection -Sl8p+t"326" -G0 -O -K << END >> $psfile
    27.233    55.140
END
gmt psxy -: -R $projection -Sl8p+t"327" -G0 -O -K << END >> $psfile
    27.167    55.069
END
gmt psxy -: -R $projection -Sl8p+t"328" -G0 -O -K << END >> $psfile
    27.250    55.113
END
gmt psxy -: -R $projection -Sl8p+t"329" -G0 -O -K << END >> $psfile
    27.254    55.065
END
gmt psxy -: -R $projection -Sl8p+t"330" -G0 -O -K << END >> $psfile
    27.254    55.064
END
gmt psxy -: -R $projection -Sl8p+t"331" -G0 -O -K << END >> $psfile
    27.263    55.026
END
gmt psxy -: -R $projection -Sl8p+t"332" -G0 -O -K << END >> $psfile
    27.267    55.040
END
gmt psxy -: -R $projection -Sl8p+t"333" -G0 -O -K << END >> $psfile
    27.261    55.034
END
gmt psxy -: -R $projection -Sl8p+t"334" -G0 -O -K << END >> $psfile
    27.216    55.060
END
gmt psxy -: -R $projection -Sl8p+t"335" -G0 -O -K << END >> $psfile
    27.227    55.108
END
gmt psxy -: -R $projection -Sl8p+t"336" -G0 -O -K << END >> $psfile
    27.279    55.017
END
gmt psxy -: -R $projection -Sl8p+t"337" -G0 -O -K << END >> $psfile
    27.236    54.977
END
gmt psxy -: -R $projection -Sl8p+t"338" -G0 -O -K << END >> $psfile
    27.196    55.104
END
gmt psxy -: -R $projection -Sl8p+t"339" -G0 -O -K << END >> $psfile
    27.166    56.000
END
gmt psxy -: -R $projection -Sl8p+t"340" -G0 -O -K << END >> $psfile
    26.708    55.096
END
gmt psxy -: -R $projection -Sl8p+t"341" -G0 -O -K << END >> $psfile
    26.642    55.465
END
gmt psxy -: -R $projection -Sl8p+t"342" -G0 -O -K << END >> $psfile
    27.053    55.917
END
gmt psxy -: -R $projection -Sl8p+t"343" -G0 -O -K << END >> $psfile
    27.053    55.876
END
gmt psxy -: -R $projection -Sl8p+t"344" -G0 -O -K << END >> $psfile
    27.052    55.889
END
gmt psxy -: -R $projection -Sl8p+t"345" -G0 -O -K << END >> $psfile
    27.055    55.885
END
gmt psxy -: -R $projection -Sl8p+t"346" -G0 -O -K << END >> $psfile
    27.051    55.848
END
gmt psxy -: -R $projection -Sl8p+t"347" -G0 -O -K << END >> $psfile
    27.057    55.923
END
gmt psxy -: -R $projection -Sl8p+t"348" -G0 -O -K << END >> $psfile
    27.164    54.850
END
gmt psxy -: -R $projection -Sl8p+t"349" -G0 -O -K << END >> $psfile
    27.189    55.115
END
gmt psxy -: -R $projection -Sl8p+t"350" -G0 -O -K << END >> $psfile
    27.317    54.915
END
gmt psxy -: -R $projection -Sl8p+t"351" -G0 -O -K << END >> $psfile
    26.836    55.823
END
gmt psxy -: -R $projection -Sl8p+t"352" -G0 -O -K << END >> $psfile
    27.118    56.221
END
gmt psxy -: -R $projection -Sl8p+t"353" -G0 -O -K << END >> $psfile
    26.605    55.588
END
gmt psxy -: -R $projection -Sl8p+t"354" -G0 -O -K << END >> $psfile
    27.358    55.402
END
gmt psxy -: -R $projection -Sl8p+t"355" -G0 -O -K << END >> $psfile
    26.747    55.963
END
gmt psxy -: -R $projection -Sl8p+t"356" -G0 -O -K << END >> $psfile
    27.338    55.431
END
gmt psxy -: -R $projection -Sl8p+t"357" -G0 -O -K << END >> $psfile
    26.700    56.406
END
gmt psxy -: -R $projection -Sl8p+t"358" -G0 -O -K << END >> $psfile
    26.964    56.165
END
gmt psxy -: -R $projection -Sl8p+t"359" -G0 -O -K << END >> $psfile
    26.949    56.132
END
gmt psxy -: -R $projection -Sl8p+t"360" -G0 -O -K << END >> $psfile
    27.362    55.415
END
gmt psxy -: -R $projection -Sl8p+t"361" -G0 -O -K << END >> $psfile
    27.190    55.125
END
gmt psxy -: -R $projection -Sl8p+t"362" -G0 -O -K << END >> $psfile
    26.853    55.350
END
gmt psxy -: -R $projection -Sl8p+t"363" -G0 -O -K << END >> $psfile
    26.859    55.266
END
gmt psxy -: -R $projection -Sl8p+t"364" -G0 -O -K << END >> $psfile
    26.792    55.279
END
gmt psxy -: -R $projection -Sl8p+t"365" -G0 -O -K << END >> $psfile
    26.849    55.281
END
gmt psxy -: -R $projection -Sl8p+t"366" -G0 -O -K << END >> $psfile
    26.848    55.285
END
gmt psxy -: -R $projection -Sl8p+t"367" -G0 -O -K << END >> $psfile
    26.912    55.486
END
gmt psxy -: -R $projection -Sl8p+t"368" -G0 -O -K << END >> $psfile
    26.796    55.262
END
gmt psxy -: -R $projection -Sl8p+t"369" -G0 -O -K << END >> $psfile
    26.822    55.325
END
gmt psxy -: -R $projection -Sl8p+t"370" -G0 -O -K << END >> $psfile
    26.846    55.267
END
gmt psxy -: -R $projection -Sl8p+t"371" -G0 -O -K << END >> $psfile
    26.848    55.341
END
gmt psxy -: -R $projection -Sl8p+t"372" -G0 -O -K << END >> $psfile
    26.904    55.557
END
gmt psxy -: -R $projection -Sl8p+t"373" -G0 -O -K << END >> $psfile
    26.780    55.168
END
gmt psxy -: -R $projection -Sl8p+t"374" -G0 -O -K << END >> $psfile
    27.361    56.147
END
gmt psxy -: -R $projection -Sl8p+t"375" -G0 -O -K << END >> $psfile
    26.649    55.518
END
gmt psxy -: -R $projection -Sl8p+t"376" -G0 -O -K << END >> $psfile
    26.950    55.729
END
gmt psxy -: -R $projection -Sl8p+t"377" -G0 -O -K << END >> $psfile
    26.827    55.318
END
gmt psxy -: -R $projection -Sl8p+t"378" -G0 -O -K << END >> $psfile
    26.969    55.010
END
gmt psxy -: -R $projection -Sl8p+t"379" -G0 -O -K << END >> $psfile
    27.404    55.318
END
gmt psxy -: -R $projection -Sl8p+t"380" -G0 -O -K << END >> $psfile
    27.406    55.298
END
gmt psxy -: -R $projection -Sl8p+t"381" -G0 -O -K << END >> $psfile
    26.817    55.168
END
gmt psxy -: -R $projection -Sl8p+t"382" -G0 -O -K << END >> $psfile
    27.266    55.637
END
gmt psxy -: -R $projection -Sl8p+t"383" -G0 -O -K << END >> $psfile
    27.290    55.573
END
gmt psxy -: -R $projection -Sl8p+t"384" -G0 -O -K << END >> $psfile
    27.299    55.645
END
gmt psxy -: -R $projection -Sl8p+t"385" -G0 -O -K << END >> $psfile
    27.278    55.590
END
gmt psxy -: -R $projection -Sl8p+t"386" -G0 -O -K << END >> $psfile
    26.842    55.283
END
gmt psxy -: -R $projection -Sl8p+t"387" -G0 -O -K << END >> $psfile
    26.828    55.226
END
gmt psxy -: -R $projection -Sl8p+t"388" -G0 -O -K << END >> $psfile
    26.820    55.337
END
gmt psxy -: -R $projection -Sl8p+t"389" -G0 -O -K << END >> $psfile
    26.845    55.343
END
gmt psxy -: -R $projection -Sl8p+t"390" -G0 -O -K << END >> $psfile
    26.809    55.375
END
gmt psxy -: -R $projection -Sl8p+t"391" -G0 -O -K << END >> $psfile
    26.851    55.296
END
gmt psxy -: -R $projection -Sl8p+t"392" -G0 -O -K << END >> $psfile
    26.799    55.348
END
gmt psxy -: -R $projection -Sl8p+t"393" -G0 -O -K << END >> $psfile
    26.811    55.279
END
gmt psxy -: -R $projection -Sl8p+t"394" -G0 -O -K << END >> $psfile
    26.854    55.367
END
gmt psxy -: -R $projection -Sl8p+t"395" -G0 -O -K << END >> $psfile
    26.801    55.318
END
gmt psxy -: -R $projection -Sl8p+t"396" -G0 -O -K << END >> $psfile
    26.765    55.697
END
gmt psxy -: -R $projection -Sl8p+t"397" -G0 -O -K << END >> $psfile
    26.837    55.261
END
gmt psxy -: -R $projection -Sl8p+t"398" -G0 -O -K << END >> $psfile
    26.835    55.384
END
gmt psxy -: -R $projection -Sl8p+t"399" -G0 -O -K << END >> $psfile
    26.861    55.355
END
gmt psxy -: -R $projection -Sl8p+t"400" -G0 -O -K << END >> $psfile
    26.853    55.363
END
gmt psxy -: -R $projection -Sl8p+t"401" -G0 -O -K << END >> $psfile
    26.850    55.153
END
gmt psxy -: -R $projection -Sl8p+t"402" -G0 -O -K << END >> $psfile
    26.834    55.211
END
gmt psxy -: -R $projection -Sl8p+t"403" -G0 -O -K << END >> $psfile
    26.785    55.267
END
gmt psxy -: -R $projection -Sl8p+t"404" -G0 -O -K << END >> $psfile
    26.861    55.283
END
gmt psxy -: -R $projection -Sl8p+t"405" -G0 -O -K << END >> $psfile
    26.858    55.266
END
gmt psxy -: -R $projection -Sl8p+t"406" -G0 -O -K << END >> $psfile
    26.824    55.378
END
gmt psxy -: -R $projection -Sl8p+t"407" -G0 -O -K << END >> $psfile
    26.840    55.267
END
gmt psxy -: -R $projection -Sl8p+t"408" -G0 -O -K << END >> $psfile
    26.844    55.274
END
gmt psxy -: -R $projection -Sl8p+t"409" -G0 -O -K << END >> $psfile
    26.848    55.164
END
gmt psxy -: -R $projection -Sl8p+t"410" -G0 -O -K << END >> $psfile
    26.809    55.362
END
gmt psxy -: -R $projection -Sl8p+t"411" -G0 -O -K << END >> $psfile
    26.801    55.293
END
gmt psxy -: -R $projection -Sl8p+t"412" -G0 -O -K << END >> $psfile
    26.809    55.358
END
gmt psxy -: -R $projection -Sl8p+t"413" -G0 -O -K << END >> $psfile
    26.824    55.326
END
gmt psxy -: -R $projection -Sl8p+t"414" -G0 -O -K << END >> $psfile
    26.824    55.172
END
gmt psxy -: -R $projection -Sl8p+t"415" -G0 -O -K << END >> $psfile
    26.833    55.295
END
gmt psxy -: -R $projection -Sl8p+t"416" -G0 -O -K << END >> $psfile
    26.842    55.288
END
gmt psxy -: -R $projection -Sl8p+t"417" -G0 -O -K << END >> $psfile
    26.784    55.369
END
gmt psxy -: -R $projection -Sl8p+t"418" -G0 -O -K << END >> $psfile
    26.806    55.273
END
gmt psxy -: -R $projection -Sl8p+t"419" -G0 -O -K << END >> $psfile
    26.857    55.336
END
gmt psxy -: -R $projection -Sl8p+t"420" -G0 -O -K << END >> $psfile
    26.833    55.324
END
gmt psxy -: -R $projection -Sl8p+t"421" -G0 -O -K << END >> $psfile
    26.799    55.314
END
gmt psxy -: -R $projection -Sl8p+t"422" -G0 -O -K << END >> $psfile
    26.813    55.389
END
gmt psxy -: -R $projection -Sl8p+t"423" -G0 -O -K << END >> $psfile
    26.778    55.358
END
gmt psxy -: -R $projection -Sl8p+t"424" -G0 -O -K << END >> $psfile
    26.798    55.301
END
gmt psxy -: -R $projection -Sl8p+t"425" -G0 -O -K << END >> $psfile
    26.911    55.443
END
gmt psxy -: -R $projection -Sl8p+t"426" -G0 -O -K << END >> $psfile
    26.807    55.386
END
gmt psxy -: -R $projection -Sl8p+t"427" -G0 -O -K << END >> $psfile
    26.867    55.365
END
gmt psxy -: -R $projection -Sl8p+t"428" -G0 -O -K << END >> $psfile
    26.856    55.209
END
gmt psxy -: -R $projection -Sl8p+t"429" -G0 -O -K << END >> $psfile
    26.743    55.285
END
gmt psxy -: -R $projection -Sl8p+t"430" -G0 -O -K << END >> $psfile
    26.797    55.328
END
gmt psxy -: -R $projection -Sl8p+t"431" -G0 -O -K << END >> $psfile
    26.875    55.425
END
gmt psxy -: -R $projection -Sl8p+t"432" -G0 -O -K << END >> $psfile
    26.792    55.256
END
gmt psxy -: -R $projection -Sl8p+t"433" -G0 -O -K << END >> $psfile
    26.809    55.307
END
gmt psxy -: -R $projection -Sl8p+t"434" -G0 -O -K << END >> $psfile
    26.794    55.321
END
gmt psxy -: -R $projection -Sl8p+t"435" -G0 -O -K << END >> $psfile
    26.800    55.279
END
gmt psxy -: -R $projection -Sl8p+t"436" -G0 -O -K << END >> $psfile
    26.797    55.286
END
gmt psxy -: -R $projection -Sl8p+t"437" -G0 -O -K << END >> $psfile
    26.778    55.274
END
gmt psxy -: -R $projection -Sl8p+t"438" -G0 -O -K << END >> $psfile
    26.806    55.309
END
gmt psxy -: -R $projection -Sl8p+t"439" -G0 -O -K << END >> $psfile
    26.814    55.324
END
gmt psxy -: -R $projection -Sl8p+t"440" -G0 -O -K << END >> $psfile
    26.806    55.348
END
gmt psxy -: -R $projection -Sl8p+t"441" -G0 -O -K << END >> $psfile
    26.798    55.282
END
gmt psxy -: -R $projection -Sl8p+t"442" -G0 -O -K << END >> $psfile
    26.801    55.289
END
gmt psxy -: -R $projection -Sl8p+t"443" -G0 -O -K << END >> $psfile
    26.830    55.333
END
gmt psxy -: -R $projection -Sl8p+t"444" -G0 -O -K << END >> $psfile
    26.844    55.428
END
gmt psxy -: -R $projection -Sl8p+t"445" -G0 -O -K << END >> $psfile
    26.861    55.356
END
gmt psxy -: -R $projection -Sl8p+t"446" -G0 -O -K << END >> $psfile
    26.850    55.392
END
gmt psxy -: -R $projection -Sl8p+t"447" -G0 -O -K << END >> $psfile
    26.851    55.355
END
gmt psxy -: -R $projection -Sl8p+t"448" -G0 -O -K << END >> $psfile
    26.822    55.313
END
gmt psxy -: -R $projection -Sl8p+t"449" -G0 -O -K << END >> $psfile
    26.892    55.378
END
gmt psxy -: -R $projection -Sl8p+t"450" -G0 -O -K << END >> $psfile
    26.871    55.363
END
gmt psxy -: -R $projection -Sl8p+t"451" -G0 -O -K << END >> $psfile
    26.829    55.333
END
gmt psxy -: -R $projection -Sl8p+t"452" -G0 -O -K << END >> $psfile
    26.806    55.282
END
gmt psxy -: -R $projection -Sl8p+t"453" -G0 -O -K << END >> $psfile
    26.856    55.400
END
gmt psxy -: -R $projection -Sl8p+t"454" -G0 -O -K << END >> $psfile
    26.806    55.316
END
gmt psxy -: -R $projection -Sl8p+t"455" -G0 -O -K << END >> $psfile
    26.790    55.251
END
gmt psxy -: -R $projection -Sl8p+t"456" -G0 -O -K << END >> $psfile
    26.832    55.352
END
gmt psxy -: -R $projection -Sl8p+t"457" -G0 -O -K << END >> $psfile
    26.864    55.246
END
gmt psxy -: -R $projection -Sl8p+t"458" -G0 -O -K << END >> $psfile
    26.844    55.334
END
gmt psxy -: -R $projection -Sl8p+t"459" -G0 -O -K << END >> $psfile
    26.830    55.377
END
gmt psxy -: -R $projection -Sl8p+t"460" -G0 -O -K << END >> $psfile
    26.801    55.303
END
gmt psxy -: -R $projection -Sl8p+t"461" -G0 -O -K << END >> $psfile
    26.820    55.354
END
gmt psxy -: -R $projection -Sl8p+t"462" -G0 -O -K << END >> $psfile
    26.859    55.421
END
gmt psxy -: -R $projection -Sl8p+t"463" -G0 -O -K << END >> $psfile
    26.789    55.280
END
gmt psxy -: -R $projection -Sl8p+t"464" -G0 -O -K << END >> $psfile
    26.831    55.331
END
gmt psxy -: -R $projection -Sl8p+t"465" -G0 -O -K << END >> $psfile
    26.828    55.163
END
gmt psxy -: -R $projection -Sl8p+t"466" -G0 -O -K << END >> $psfile
    26.812    55.316
END
gmt psxy -: -R $projection -Sl8p+t"467" -G0 -O -K << END >> $psfile
    26.828    55.342
END
gmt psxy -: -R $projection -Sl8p+t"468" -G0 -O -K << END >> $psfile
    26.795    55.278
END
gmt psxy -: -R $projection -Sl8p+t"469" -G0 -O -K << END >> $psfile
    26.820    55.445
END
gmt psxy -: -R $projection -Sl8p+t"470" -G0 -O -K << END >> $psfile
    27.210    55.480
END
gmt psxy -: -R $projection -Sl8p+t"471" -G0 -O -K << END >> $psfile
    26.853    55.244
END
gmt psxy -: -R $projection -Sl8p+t"472" -G0 -O -K << END >> $psfile
    27.395    56.065
END
gmt psxy -: -R $projection -Sl8p+t"473" -G0 -O -K << END >> $psfile
    26.819    55.310
END
gmt psxy -: -R $projection -Sl8p+t"474" -G0 -O -K << END >> $psfile
    26.845    55.401
END
gmt psxy -: -R $projection -Sl8p+t"475" -G0 -O -K << END >> $psfile
    26.852    55.315
END
gmt psxy -: -R $projection -Sl8p+t"476" -G0 -O -K << END >> $psfile
    26.824    55.365
END
gmt psxy -: -R $projection -Sl8p+t"477" -G0 -O -K << END >> $psfile
    26.792    55.231
END
gmt psxy -: -R $projection -Sl8p+t"478" -G0 -O -K << END >> $psfile
    26.826    55.368
END
gmt psxy -: -R $projection -Sl8p+t"479" -G0 -O -K << END >> $psfile
    26.779    55.326
END
gmt psxy -: -R $projection -Sl8p+t"480" -G0 -O -K << END >> $psfile
    26.837    55.283
END
gmt psxy -: -R $projection -Sl8p+t"481" -G0 -O -K << END >> $psfile
    26.829    55.331
END
gmt psxy -: -R $projection -Sl8p+t"482" -G0 -O -K << END >> $psfile
    26.842    55.371
END
gmt psxy -: -R $projection -Sl8p+t"483" -G0 -O -K << END >> $psfile
    26.717    55.183
END
gmt psxy -: -R $projection -Sl8p+t"484" -G0 -O -K << END >> $psfile
    26.828    55.300
END
gmt psxy -: -R $projection -Sl8p+t"485" -G0 -O -K << END >> $psfile
    26.844    55.320
END
gmt psxy -: -R $projection -Sl8p+t"486" -G0 -O -K << END >> $psfile
    26.737    55.055
END
gmt psxy -: -R $projection -Sl8p+t"487" -G0 -O -K << END >> $psfile
    26.868    55.379
END
gmt psxy -: -R $projection -Sl8p+t"488" -G0 -O -K << END >> $psfile
    26.861    55.291
END
gmt psxy -: -R $projection -Sl8p+t"489" -G0 -O -K << END >> $psfile
    26.815    55.330
END
gmt psxy -: -R $projection -Sl8p+t"490" -G0 -O -K << END >> $psfile
    26.796    55.382
END
gmt psxy -: -R $projection -Sl8p+t"491" -G0 -O -K << END >> $psfile
    27.752    55.401
END
gmt psxy -: -R $projection -Sl8p+t"492" -G0 -O -K << END >> $psfile
    27.742    55.378
END
gmt psxy -: -R $projection -Sl8p+t"493" -G0 -O -K << END >> $psfile
    26.801    55.288
END
gmt psxy -: -R $projection -Sl8p+t"494" -G0 -O -K << END >> $psfile
    27.231    55.188
END
gmt psxy -: -R $projection -Sl8p+t"495" -G0 -O -K << END >> $psfile
    26.824    55.248
END
gmt psxy -: -R $projection -Sl8p+t"496" -G0 -O -K << END >> $psfile
    26.855    55.257
END
gmt psxy -: -R $projection -Sl8p+t"497" -G0 -O -K << END >> $psfile
    26.748    55.070
END
gmt psxy -: -R $projection -Sl8p+t"498" -G0 -O -K << END >> $psfile
    26.925    56.088
END
gmt psxy -: -R $projection -Sl8p+t"499" -G0 -O -K << END >> $psfile
    27.150    55.785
END
gmt psxy -: -R $projection -Sl8p+t"500" -G0 -O -K << END >> $psfile
    26.828    55.428
END

# Change in location, calibration shift if available
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.023    55.531
    27.024    55.532
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.007    55.463
    27.024    55.532
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.045    55.608
    27.046    55.608
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.920    55.557
    27.046    55.608
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.071    55.573
    27.066    55.573
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.022    55.544
    27.066    55.573
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.037    55.538
    27.034    55.540
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.004    55.578
    27.034    55.540
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.314    55.032
    27.315    55.032
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.262    55.066
    27.315    55.032
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.057    55.487
    27.057    55.488
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.931    55.404
    27.057    55.488
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.110    55.349
    27.111    55.350
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.156    55.349
    27.111    55.350
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.106    55.371
    27.109    55.372
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.127    55.408
    27.109    55.372
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.072    55.479
    27.072    55.482
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.051    55.464
    27.072    55.482
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.839    54.947
    27.842    54.950
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.766    54.968
    27.842    54.950
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.301    54.971
    27.301    54.971
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.195    54.936
    27.301    54.971
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.386    56.144
    27.386    56.144
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.380    56.116
    27.386    56.144
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.132    55.422
    27.131    55.423
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.181    55.504
    27.131    55.423
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.123    55.441
    27.120    55.441
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.031    55.331
    27.120    55.441
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.161    55.949
    27.160    55.948
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.124    55.892
    27.160    55.948
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.874    55.787
    26.875    55.787
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.861    55.621
    26.875    55.787
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.733    54.980
    26.733    54.981
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.638    54.874
    26.733    54.981
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.702    54.909
    26.705    54.909
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.628    54.873
    26.705    54.909
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.974    56.221
    26.975    56.222
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.944    56.319
    26.975    56.222
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.770    55.049
    26.770    55.049
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.702    55.087
    26.770    55.049
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.429    56.197
    27.430    56.197
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.399    56.113
    27.430    56.197
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.795    55.981
    26.796    55.981
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.772    55.927
    26.796    55.981
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.372    55.850
    27.374    55.850
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.351    55.788
    27.374    55.850
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.313    54.982
    27.315    54.983
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.159    54.866
    27.315    54.983
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.965    54.910
    26.968    54.910
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.860    54.850
    26.968    54.910
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.387    56.175
    27.388    56.174
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.304    56.133
    27.388    56.174
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.929    54.882
    26.930    54.882
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.919    54.810
    26.930    54.882
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.052    55.642
    27.053    55.641
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.022    55.565
    27.053    55.641
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.658    55.897
    26.659    55.897
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.658    55.760
    26.659    55.897
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.414    56.207
    27.414    56.208
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.221    56.075
    27.414    56.208
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.292    56.112
    27.292    56.111
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.303    56.031
    27.292    56.111
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.082    56.079
    27.082    56.079
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.078    55.960
    27.082    56.079
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.836    55.896
    26.837    55.896
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.786    55.872
    26.837    55.896
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.851    55.873
    26.851    55.873
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.851    55.747
    26.851    55.873
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.796    55.865
    26.797    55.865
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.780    55.799
    26.797    55.865
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.825    55.893
    26.825    55.894
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.819    55.729
    26.825    55.894
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.804    55.933
    26.804    55.931
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.683    55.864
    26.804    55.931
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.847    55.859
    26.847    55.859
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.851    55.697
    26.847    55.859
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.895    55.839
    26.895    55.839
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.845    55.786
    26.895    55.839
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.830    55.898
    26.830    55.898
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.774    55.819
    26.830    55.898
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.815    55.887
    26.816    55.887
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.765    55.650
    26.816    55.887
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.834    55.904
    26.835    55.904
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.842    55.712
    26.835    55.904
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.813    55.867
    26.814    55.867
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.820    55.716
    26.814    55.867
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.808    55.903
    26.809    55.903
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.763    55.838
    26.809    55.903
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.836    55.791
    26.836    55.791
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.822    55.630
    26.836    55.791
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.809    55.903
    26.809    55.903
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.778    55.789
    26.809    55.903
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.798    55.900
    26.798    55.900
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.802    55.790
    26.798    55.900
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.860    55.982
    26.861    55.982
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.840    56.002
    26.861    55.982
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.823    55.885
    26.823    55.885
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.813    55.820
    26.823    55.885
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.901    55.917
    26.901    55.917
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.894    55.925
    26.901    55.917
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.852    55.958
    26.852    55.959
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.855    55.788
    26.852    55.959
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.823    55.919
    26.823    55.918
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.813    55.923
    26.823    55.918
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.864    55.963
    26.864    55.963
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.857    55.976
    26.864    55.963
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.898    55.933
    26.898    55.933
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.892    55.943
    26.898    55.933
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.847    55.970
    26.847    55.970
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.834    55.986
    26.847    55.970
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.837    55.976
    26.837    55.976
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.825    55.985
    26.837    55.976
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.864    55.964
    26.864    55.964
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.873    55.957
    26.864    55.964
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.874    55.951
    26.874    55.951
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.870    55.966
    26.874    55.951
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.820    55.965
    26.820    55.965
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.804    55.986
    26.820    55.965
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.838    55.943
    26.838    55.942
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.876    55.833
    26.838    55.942
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.819    55.941
    26.819    55.940
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.806    55.956
    26.819    55.940
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.822    55.909
    26.822    55.909
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.815    55.921
    26.822    55.909
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.833    55.852
    26.833    55.852
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.752    55.798
    26.833    55.852
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.853    55.929
    26.853    55.929
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.846    55.945
    26.853    55.929
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.823    55.887
    26.823    55.887
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.805    55.897
    26.823    55.887
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.851    55.961
    26.851    55.961
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.838    55.933
    26.851    55.961
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.821    55.960
    26.821    55.960
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.800    55.981
    26.821    55.960
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.340    54.959
    27.341    54.959
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.337    54.871
    27.341    54.959
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.886    55.920
    26.886    55.920
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.890    55.928
    26.886    55.920
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.820    55.898
    26.820    55.898
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.808    55.905
    26.820    55.898
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.907    55.741
    26.908    55.741
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.877    55.679
    26.908    55.741
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.503    55.492
    27.503    55.492
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.436    55.428
    27.503    55.492
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.480    55.385
    27.480    55.385
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.475    55.429
    27.480    55.385
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.824    55.941
    26.824    55.941
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.779    55.784
    26.824    55.941
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.825    55.888
    26.825    55.889
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.844    55.794
    26.825    55.889
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.744    55.403
    27.745    55.403
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.629    55.325
    27.745    55.403
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.736    55.434
    27.736    55.433
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.752    55.471
    27.736    55.433
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.372    54.946
    27.372    54.946
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.353    54.912
    27.372    54.946
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.826    55.944
    26.826    55.944
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.791    55.888
    26.826    55.944
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.831    55.935
    26.831    55.935
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.820    55.881
    26.831    55.935
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.849    55.967
    26.850    55.969
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.804    55.789
    26.850    55.969
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.894    55.967
    26.894    55.967
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.847    55.830
    26.894    55.967
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.913    55.890
    26.911    55.889
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.838    55.868
    26.911    55.889
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.931    55.876
    26.932    55.877
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.874    55.850
    26.932    55.877
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.944    55.940
    26.945    55.941
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.884    55.848
    26.945    55.941
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.899    55.892
    26.899    55.892
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.896    55.778
    26.899    55.892
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.874    55.871
    26.874    55.871
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.838    55.722
    26.874    55.871
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.844    55.922
    26.844    55.922
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.810    55.836
    26.844    55.922
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.910    55.938
    26.910    55.938
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.844    55.835
    26.910    55.938
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.928    55.898
    26.928    55.898
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.965    55.772
    26.928    55.898
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.933    55.918
    26.933    55.919
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.917    55.815
    26.933    55.919
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.973    55.923
    26.973    55.923
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.973    55.877
    26.973    55.923
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.892    55.893
    26.893    55.892
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.869    55.806
    26.893    55.892
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.917    55.939
    26.917    55.939
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.894    55.864
    26.917    55.939
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.941    55.935
    26.941    55.935
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.905    55.842
    26.941    55.935
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.871    55.887
    26.871    55.886
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.814    55.813
    26.871    55.886
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.868    55.843
    26.868    55.843
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.857    55.755
    26.868    55.843
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.850    55.906
    26.850    55.906
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.884    55.795
    26.850    55.906
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.587    55.294
    27.587    55.294
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.537    55.185
    27.587    55.294
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.731    55.158
    27.731    55.158
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.739    55.108
    27.731    55.158
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.934    55.926
    26.934    55.926
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.934    55.806
    26.934    55.926
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.603    55.290
    27.603    55.289
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.542    55.204
    27.603    55.289
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.890    55.914
    26.890    55.914
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.894    55.824
    26.890    55.914
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.901    55.942
    26.901    55.941
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.879    55.893
    26.901    55.941
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.918    55.905
    26.918    55.905
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.897    55.846
    26.918    55.905
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.780    55.830
    26.780    55.830
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.767    55.731
    26.780    55.830
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.605    55.263
    27.605    55.262
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.579    55.215
    27.605    55.262
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.014    54.972
    27.014    54.971
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.941    54.836
    27.014    54.971
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.604    55.405
    27.604    55.406
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.563    55.343
    27.604    55.406
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.614    55.449
    27.615    55.450
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.559    55.431
    27.615    55.450
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.877    56.334
    26.877    56.335
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.850    56.221
    26.877    56.335
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.842    55.340
    26.842    55.340
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.778    55.276
    26.842    55.340
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.875    56.292
    26.875    56.291
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.876    56.160
    26.875    56.291
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.417    56.007
    27.417    56.006
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.259    55.995
    27.417    56.006
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.375    55.986
    27.374    55.986
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.271    55.919
    27.374    55.986
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.744    55.046
    27.749    55.041
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.637    54.970
    27.749    55.041
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.343    55.981
    27.343    55.981
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.345    55.949
    27.343    55.981
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.813    55.236
    27.814    55.236
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.744    55.146
    27.814    55.236
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.860    55.898
    26.860    55.898
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.836    55.862
    26.860    55.898
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.851    55.892
    26.851    55.892
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.795    55.841
    26.851    55.892
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.886    55.897
    26.886    55.896
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.875    55.801
    26.886    55.896
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.908    55.867
    26.908    55.867
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.990    55.806
    26.908    55.867
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.851    55.898
    26.852    55.898
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.815    55.824
    26.852    55.898
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.947    55.858
    26.947    55.858
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.231    55.314
    26.947    55.858
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.912    55.936
    26.912    55.936
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.897    55.874
    26.912    55.936
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.856    55.845
    26.856    55.845
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.863    55.763
    26.856    55.845
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.851    55.877
    26.851    55.876
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.865    55.795
    26.851    55.876
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.872    55.947
    26.872    55.946
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.902    55.836
    26.872    55.946
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.904    55.925
    26.904    55.925
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.868    55.833
    26.904    55.925
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.867    55.856
    26.868    55.855
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.825    55.806
    26.868    55.855
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.875    55.860
    26.875    55.859
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.815    55.799
    26.875    55.859
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.865    55.854
    26.865    55.854
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.879    55.747
    26.865    55.854
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.867    55.899
    26.867    55.899
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.851    55.825
    26.867    55.899
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.946    56.080
    26.946    56.079
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.920    56.062
    26.946    56.079
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.975    56.127
    26.975    56.127
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.910    56.150
    26.975    56.127
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.991    56.116
    26.991    56.116
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.967    56.069
    26.991    56.116
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.993    56.104
    26.993    56.104
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.028    56.097
    26.993    56.104
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.982    56.084
    26.982    56.084
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.951    56.040
    26.982    56.084
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.004    56.112
    27.004    56.112
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.978    56.113
    27.004    56.112
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.885    56.173
    26.885    56.173
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.894    55.957
    26.885    56.173
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.978    56.070
    26.978    56.070
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.953    56.011
    26.978    56.070
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.944    55.863
    26.944    55.863
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.933    55.805
    26.944    55.863
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.936    56.016
    26.936    56.016
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.901    55.962
    26.936    56.016
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.957    56.175
    26.957    56.175
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.962    56.091
    26.957    56.175
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.899    55.915
    26.899    55.915
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.907    55.800
    26.899    55.915
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.382    56.026
    27.381    56.026
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.329    55.956
    27.381    56.026
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.972    56.168
    26.972    56.168
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.965    56.041
    26.972    56.168
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.970    56.102
    26.970    56.102
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.911    56.077
    26.970    56.102
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.982    56.143
    26.982    56.143
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.993    55.980
    26.982    56.143
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.970    56.124
    26.971    56.124
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.978    56.047
    26.971    56.124
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.967    56.135
    26.968    56.134
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.974    56.000
    26.968    56.134
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.954    56.120
    26.954    56.120
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.938    56.000
    26.954    56.120
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.435    56.161
    27.435    56.161
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.360    56.218
    27.435    56.161
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.808    55.896
    26.808    55.896
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.812    55.834
    26.808    55.896
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.679    55.126
    26.679    55.126
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.668    54.998
    26.679    55.126
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.918    55.943
    26.919    55.943
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.885    55.898
    26.919    55.943
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.779    55.037
    26.779    55.037
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.847    54.966
    26.779    55.037
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.701    55.040
    26.701    55.042
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.686    54.951
    26.701    55.042
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.724    55.086
    26.725    55.086
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.613    55.060
    26.725    55.086
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.678    55.121
    26.678    55.121
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.677    55.045
    26.678    55.121
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.853    55.863
    26.853    55.863
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.822    55.817
    26.853    55.863
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.621    55.061
    26.621    55.061
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.566    55.027
    26.621    55.061
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.897    55.918
    26.897    55.918
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.889    55.772
    26.897    55.918
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.961    55.941
    26.961    55.941
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.894    55.901
    26.961    55.941
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.958    55.926
    26.958    55.925
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.915    55.839
    26.958    55.925
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.959    55.947
    26.961    55.948
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.937    55.938
    26.961    55.948
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.942    55.930
    26.942    55.930
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.912    55.877
    26.942    55.930
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.005    55.931
    27.006    55.931
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.107    55.843
    27.006    55.931
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.876    55.907
    26.878    55.905
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.746    55.868
    26.878    55.905
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.960    56.046
    26.960    56.045
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.932    56.020
    26.960    56.045
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.927    56.003
    26.927    56.003
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.926    55.931
    26.927    56.003
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.589    55.498
    27.589    55.498
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.517    55.489
    27.589    55.498
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.160    55.851
    27.160    55.851
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.117    55.837
    27.160    55.851
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.929    55.935
    26.929    55.935
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.878    55.914
    26.929    55.935
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.814    55.827
    26.814    55.827
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.805    55.756
    26.814    55.827
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.801    55.807
    26.801    55.806
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.780    55.669
    26.801    55.806
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.791    55.856
    26.791    55.855
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.774    55.773
    26.791    55.855
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.793    55.849
    26.794    55.849
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.735    55.885
    26.794    55.849
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.195    56.116
    27.196    56.116
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.149    56.057
    27.196    56.116
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.246    56.222
    27.247    56.222
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.264    56.212
    27.247    56.222
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.230    56.266
    27.231    56.266
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.221    56.236
    27.231    56.266
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.957    56.059
    26.957    56.059
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.885    56.028
    26.957    56.059
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.608    55.239
    27.609    55.239
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.519    55.180
    27.609    55.239
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.187    55.604
    27.187    55.604
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.100    55.579
    27.187    55.604
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.197    55.609
    27.198    55.609
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.142    55.494
    27.198    55.609
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.221    55.018
    27.221    55.018
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.112    54.890
    27.221    55.018
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.212    54.949
    27.212    54.949
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.151    54.865
    27.212    54.949
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.188    54.920
    27.188    54.921
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.129    54.883
    27.188    54.921
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.406    56.170
    27.406    56.170
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.322    56.090
    27.406    56.170
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.952    55.713
    26.952    55.712
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.955    55.536
    26.952    55.712
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.064    55.666
    27.064    55.666
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.003    55.688
    27.064    55.666
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.519    55.356
    27.519    55.356
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.418    55.296
    27.519    55.356
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.334    55.978
    27.334    55.977
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.347    55.953
    27.334    55.977
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.872    55.943
    26.873    55.944
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.889    55.964
    26.873    55.944
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.318    56.478
    27.318    56.478
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.274    56.448
    27.318    56.478
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.378    55.669
    27.378    55.669
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.325    55.692
    27.378    55.669
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.677    55.453
    26.677    55.453
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.670    55.463
    26.677    55.453
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.751    55.018
    27.751    55.017
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.588    54.970
    27.751    55.017
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.691    55.343
    26.691    55.342
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.650    55.294
    26.691    55.342
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.899    55.863
    26.899    55.862
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.822    55.773
    26.899    55.862
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.690    55.098
    26.690    55.098
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.780    55.097
    26.690    55.098
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.093    55.708
    27.095    55.709
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.135    55.690
    27.095    55.709
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.177    54.831
    27.176    54.830
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.101    54.840
    27.176    54.830
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.153    54.884
    27.153    54.884
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.062    54.845
    27.153    54.884
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.975    55.110
    26.975    55.109
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.963    55.037
    26.975    55.109
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.280    55.645
    27.277    55.646
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.303    55.598
    27.277    55.646
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.102    56.267
    27.103    56.267
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.138    56.293
    27.103    56.267
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.911    56.119
    26.912    56.119
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.917    56.019
    26.912    56.119
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.031    55.081
    27.031    55.080
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.981    54.999
    27.031    55.080
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.039    56.220
    27.039    56.220
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.038    56.135
    27.039    56.220
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.789    55.268
    26.789    55.269
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.726    55.279
    26.789    55.269
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.309    55.021
    27.310    55.020
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.184    54.982
    27.310    55.020
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.254    55.017
    27.254    55.017
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.184    54.960
    27.254    55.017
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.310    54.995
    27.311    54.994
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.178    54.987
    27.311    54.994
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.326    55.007
    27.326    55.006
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.269    55.014
    27.326    55.006
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.237    55.004
    27.238    55.003
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.236    54.954
    27.238    55.003
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.317    55.018
    27.317    55.019
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.353    55.099
    27.317    55.019
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.322    55.020
    27.322    55.020
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.260    55.039
    27.322    55.020
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.927    54.958
    26.927    54.959
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.905    54.967
    26.927    54.959
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.250    55.877
    27.250    55.876
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.254    55.827
    27.250    55.876
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.952    54.913
    26.952    54.913
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.986    54.911
    26.952    54.913
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.738    55.096
    26.739    55.096
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.752    55.102
    26.739    55.096
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.585    55.859
    26.581    55.859
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.591    55.793
    26.581    55.859
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.890    55.400
    26.890    55.400
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.916    55.425
    26.890    55.400
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.916    55.963
    26.916    55.964
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.926    56.038
    26.916    55.964
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.898    54.895
    26.898    54.895
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.893    54.865
    26.898    54.895
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.861    55.933
    26.861    55.932
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.851    55.937
    26.861    55.932
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.853    55.945
    26.853    55.945
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.769    55.928
    26.853    55.945
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.317    54.867
    27.318    54.867
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.259    54.808
    27.318    54.867
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.213    55.184
    27.213    55.184
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.152    55.152
    27.213    55.184
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.566    55.319
    26.566    55.318
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.606    55.405
    26.566    55.318
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.290    55.768
    27.289    55.766
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.319    55.809
    27.289    55.766
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.246    55.961
    27.246    55.961
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.278    56.003
    27.246    55.961
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.243    54.974
    27.243    54.973
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.215    54.984
    27.243    54.973
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.223    55.013
    27.226    55.022
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.191    54.985
    27.226    55.022
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.787    54.898
    26.788    54.898
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.722    54.857
    26.788    54.898
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.805    54.924
    26.806    54.924
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.710    54.845
    26.806    54.924
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.571    55.869
    26.571    55.869
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.583    55.865
    26.571    55.869
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.735    55.054
    27.735    55.053
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.589    55.013
    27.735    55.053
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.017    55.163
    27.015    55.164
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.963    55.134
    27.015    55.164
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.161    55.117
    27.162    55.116
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.121    55.066
    27.162    55.116
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.177    55.137
    27.177    55.138
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.088    55.099
    27.177    55.138
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.548    55.223
    26.548    55.222
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.546    55.182
    26.548    55.222
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.639    55.471
    26.640    55.471
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.598    55.416
    26.640    55.471
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.518    55.045
    26.517    55.048
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.506    55.089
    26.517    55.048
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.308    54.907
    27.308    54.907
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.219    54.883
    27.308    54.907
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.203    55.140
    27.203    55.141
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.103    55.091
    27.203    55.141
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.987    54.940
    26.987    54.940
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.923    54.876
    26.987    54.940
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.966    54.925
    26.967    54.926
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.010    54.881
    26.967    54.926
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.515    55.847
    26.517    55.850
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.484    55.824
    26.517    55.850
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.509    55.763
    26.509    55.763
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.595    55.820
    26.509    55.763
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.096    56.067
    27.095    56.069
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.089    56.094
    27.095    56.069
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.476    55.671
    26.478    55.671
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.433    55.678
    26.478    55.671
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.464    55.714
    26.464    55.713
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.449    55.678
    26.464    55.713
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.110    56.059
    27.110    56.060
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.127    56.071
    27.110    56.060
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.940    54.897
    26.940    54.897
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.901    54.860
    26.940    54.897
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.645    55.512
    26.646    55.512
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.612    55.471
    26.646    55.512
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.841    55.385
    26.842    55.384
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.851    55.431
    26.842    55.384
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.344    56.146
    27.345    56.145
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.324    56.112
    27.345    56.145
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.358    54.916
    27.358    54.915
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.392    54.909
    27.358    54.915
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.738    55.189
    27.739    55.192
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.679    55.139
    27.739    55.192
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.620    55.382
    27.620    55.382
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.619    55.346
    27.620    55.382
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.868    55.983
    26.868    55.982
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.878    55.896
    26.868    55.982
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.985    54.872
    26.985    54.873
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.954    54.841
    26.985    54.873
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.931    55.972
    26.931    55.972
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.930    55.983
    26.931    55.972
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.607    55.718
    26.608    55.718
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.615    55.716
    26.608    55.718
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.406    56.194
    27.406    56.194
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.324    56.207
    27.406    56.194
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.817    55.225
    26.817    55.226
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.783    55.236
    26.817    55.226
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.545    56.419
    26.545    56.419
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.473    56.464
    26.545    56.419
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.397    56.399
    27.397    56.399
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.376    56.397
    27.397    56.399
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.719    55.618
    26.719    55.619
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.745    55.699
    26.719    55.619
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.922    55.905
    26.922    55.905
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.968    55.867
    26.922    55.905
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.046    55.154
    27.046    55.154
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.004    55.147
    27.046    55.154
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.145    56.008
    27.145    56.008
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.115    56.114
    27.145    56.008
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.597    54.962
    27.597    54.962
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.508    54.892
    27.597    54.962
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.623    54.943
    27.623    54.944
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.594    54.969
    27.623    54.944
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.598    54.983
    27.598    54.983
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.550    54.992
    27.598    54.983
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.594    55.006
    27.594    55.006
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.527    54.962
    27.594    55.006
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.613    54.955
    27.614    54.954
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.623    54.949
    27.614    54.954
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.622    54.987
    27.622    54.986
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.565    54.923
    27.622    54.986
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.079    55.142
    27.078    55.142
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.031    55.125
    27.078    55.142
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.613    54.996
    27.613    54.996
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.627    54.995
    27.613    54.996
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.226    56.256
    27.224    56.256
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.190    56.225
    27.224    56.256
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.706    54.945
    27.706    54.945
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.664    54.941
    27.706    54.945
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.392    56.275
    27.392    56.274
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.383    56.264
    27.392    56.274
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.907    55.813
    26.906    55.817
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.879    55.903
    26.906    55.817
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.170    55.851
    27.170    55.852
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.141    55.817
    27.170    55.852
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.046    55.693
    27.046    55.692
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.081    55.626
    27.046    55.692
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.037    55.678
    27.037    55.679
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.053    55.703
    27.037    55.679
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.972    55.712
    26.972    55.712
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.932    55.710
    26.972    55.712
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.043    55.688
    27.043    55.688
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.037    55.596
    27.043    55.688
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.013    55.143
    27.013    55.143
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.037    55.073
    27.013    55.143
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.082    55.275
    27.082    55.275
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.057    55.276
    27.082    55.275
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.150    55.879
    27.150    55.879
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.199    55.851
    27.150    55.879
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.839    55.358
    26.839    55.358
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.827    55.286
    26.839    55.358
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.031    55.681
    27.031    55.680
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.056    55.677
    27.031    55.680
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.864    55.375
    26.864    55.376
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.933    55.387
    26.864    55.376
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.180    54.896
    27.180    54.896
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.162    54.867
    27.180    54.896
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.709    55.150
    26.710    55.150
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.702    55.030
    26.710    55.150
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.710    55.101
    26.710    55.102
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.692    55.127
    26.710    55.102
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.728    55.121
    26.728    55.122
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.827    55.161
    26.728    55.122
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.692    55.127
    26.691    55.128
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.598    55.059
    26.691    55.128
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.596    55.473
    26.596    55.474
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.590    55.462
    26.596    55.474
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.695    56.261
    26.695    56.260
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.670    56.241
    26.695    56.260
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.927    55.703
    26.927    55.703
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.921    55.664
    26.927    55.703
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.940    55.697
    26.940    55.697
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.909    55.685
    26.940    55.697
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.929    55.696
    26.929    55.697
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.982    55.682
    26.929    55.697
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.935    55.688
    26.936    55.689
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.957    55.670
    26.936    55.689
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.214    54.850
    27.214    54.850
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.152    54.822
    27.214    54.850
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.675    55.288
    26.675    55.287
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.610    55.229
    26.675    55.287
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.658    55.270
    26.658    55.269
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.598    55.255
    26.658    55.269
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.199    55.153
    27.199    55.153
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.176    55.020
    27.199    55.153
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.192    55.089
    27.192    55.089
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.167    55.068
    27.192    55.089
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.231    55.073
    27.232    55.071
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.245    55.031
    27.232    55.071
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.189    55.105
    27.189    55.106
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.139    55.073
    27.189    55.106
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.221    55.069
    27.221    55.071
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.178    55.037
    27.221    55.071
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.222    55.069
    27.222    55.069
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.186    55.008
    27.222    55.069
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.196    55.106
    27.196    55.106
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.161    55.033
    27.196    55.106
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.195    55.113
    27.195    55.113
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.137    55.096
    27.195    55.113
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.179    55.142
    27.180    55.141
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.129    55.131
    27.180    55.141
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.209    55.088
    27.209    55.088
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.123    55.051
    27.209    55.088
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.665    55.261
    26.665    55.261
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.831    55.246
    26.665    55.261
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.178    55.096
    27.179    55.096
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.057    55.052
    27.179    55.096
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.201    55.082
    27.201    55.082
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.174    55.039
    27.201    55.082
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.184    55.087
    27.185    55.087
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.088    55.050
    27.185    55.087
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.233    55.140
    27.233    55.140
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.200    55.101
    27.233    55.140
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.167    55.069
    27.167    55.069
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.254    55.084
    27.167    55.069
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.250    55.114
    27.250    55.113
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.290    54.991
    27.250    55.113
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.255    55.065
    27.254    55.065
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.219    55.054
    27.254    55.065
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.254    55.065
    27.254    55.064
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.278    55.063
    27.254    55.064
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.263    55.026
    27.263    55.026
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.261    54.942
    27.263    55.026
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.267    55.040
    27.267    55.040
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.286    54.938
    27.267    55.040
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.260    55.034
    27.261    55.034
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.390    55.045
    27.261    55.034
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.216    55.060
    27.216    55.060
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.105    55.031
    27.216    55.060
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.227    55.108
    27.227    55.108
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.148    55.053
    27.227    55.108
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.279    55.017
    27.279    55.017
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.269    54.923
    27.279    55.017
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.236    54.977
    27.236    54.977
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.199    54.953
    27.236    54.977
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.196    55.104
    27.196    55.104
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.167    55.075
    27.196    55.104
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.164    55.999
    27.166    56.000
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.189    56.023
    27.166    56.000
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.708    55.095
    26.708    55.096
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.736    55.091
    26.708    55.096
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.642    55.465
    26.642    55.465
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.653    55.394
    26.642    55.465
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.053    55.917
    27.053    55.917
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.058    55.909
    27.053    55.917
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.052    55.875
    27.053    55.876
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.076    55.882
    27.053    55.876
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.052    55.888
    27.052    55.889
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.051    55.863
    27.052    55.889
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.054    55.886
    27.055    55.885
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.087    55.820
    27.055    55.885
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.049    55.848
    27.051    55.848
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.072    55.798
    27.051    55.848
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.057    55.923
    27.057    55.923
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.017    55.888
    27.057    55.923
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.164    54.851
    27.164    54.850
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.170    54.814
    27.164    54.850
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.190    55.114
    27.189    55.115
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.156    55.126
    27.189    55.115
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.316    54.922
    27.317    54.915
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.315    54.817
    27.317    54.915
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.836    55.823
    26.836    55.823
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.846    55.764
    26.836    55.823
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.118    56.221
    27.118    56.221
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.122    56.220
    27.118    56.221
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.605    55.588
    26.605    55.588
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.592    55.491
    26.605    55.588
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.358    55.403
    27.358    55.402
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.320    55.359
    27.358    55.402
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.747    55.963
    26.747    55.963
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.800    55.879
    26.747    55.963
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.338    55.430
    27.338    55.431
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.413    55.520
    27.338    55.431
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.701    56.406
    26.700    56.406
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.851    56.196
    26.700    56.406
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.964    56.166
    26.964    56.165
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.946    56.226
    26.964    56.165
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.951    56.134
    26.949    56.132
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.936    56.081
    26.949    56.132
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.361    55.415
    27.362    55.415
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.304    55.388
    27.362    55.415
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.189    55.126
    27.190    55.125
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.111    55.098
    27.190    55.125
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.853    55.351
    26.853    55.350
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.865    55.236
    26.853    55.350
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.859    55.266
    26.859    55.266
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.861    55.285
    26.859    55.266
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.792    55.280
    26.792    55.279
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.817    55.234
    26.792    55.279
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.848    55.281
    26.849    55.281
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.840    55.224
    26.849    55.281
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.848    55.285
    26.848    55.285
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.794    55.250
    26.848    55.285
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.912    55.484
    26.912    55.486
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.892    55.433
    26.912    55.486
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.795    55.262
    26.796    55.262
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.772    55.201
    26.796    55.262
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.822    55.325
    26.822    55.325
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.816    55.298
    26.822    55.325
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.846    55.268
    26.846    55.267
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.952    55.376
    26.846    55.267
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.848    55.341
    26.848    55.341
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.845    55.301
    26.848    55.341
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.904    55.557
    26.904    55.557
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.920    55.522
    26.904    55.557
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.780    55.168
    26.780    55.168
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.781    55.241
    26.780    55.168
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.361    56.146
    27.361    56.147
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.351    56.158
    27.361    56.147
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.649    55.518
    26.649    55.518
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.624    55.458
    26.649    55.518
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.950    55.729
    26.950    55.729
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.925    55.759
    26.950    55.729
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.827    55.318
    26.827    55.318
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.786    55.290
    26.827    55.318
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.969    55.010
    26.969    55.010
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.964    54.984
    26.969    55.010
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.404    55.319
    27.404    55.318
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.373    55.250
    27.404    55.318
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.406    55.299
    27.406    55.298
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.310    55.185
    27.406    55.298
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.817    55.168
    26.817    55.168
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.752    55.142
    26.817    55.168
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.266    55.637
    27.266    55.637
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.278    55.568
    27.266    55.637
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.290    55.574
    27.290    55.573
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.284    55.571
    27.290    55.573
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.299    55.645
    27.299    55.645
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.368    55.685
    27.299    55.645
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.278    55.590
    27.278    55.590
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.345    55.625
    27.278    55.590
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.843    55.284
    26.842    55.283
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.906    55.239
    26.842    55.283
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.828    55.228
    26.828    55.226
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.825    55.159
    26.828    55.226
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.820    55.337
    26.820    55.337
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.800    55.271
    26.820    55.337
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.845    55.343
    26.845    55.343
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.809    55.262
    26.845    55.343
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.809    55.376
    26.809    55.375
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.796    55.327
    26.809    55.375
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.851    55.297
    26.851    55.296
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.884    55.257
    26.851    55.296
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.798    55.348
    26.799    55.348
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.799    55.325
    26.799    55.348
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.811    55.280
    26.811    55.279
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.795    55.232
    26.811    55.279
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.854    55.367
    26.854    55.367
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.826    55.333
    26.854    55.367
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.801    55.319
    26.801    55.318
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.776    55.343
    26.801    55.318
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.765    55.697
    26.765    55.697
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.824    55.464
    26.765    55.697
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.837    55.261
    26.837    55.261
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.858    55.294
    26.837    55.261
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.835    55.384
    26.835    55.384
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.855    55.346
    26.835    55.384
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.861    55.355
    26.861    55.355
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.832    55.343
    26.861    55.355
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.853    55.363
    26.853    55.363
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.821    55.291
    26.853    55.363
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.851    55.157
    26.850    55.153
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.835    55.123
    26.850    55.153
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.834    55.212
    26.834    55.211
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.810    55.233
    26.834    55.211
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.785    55.267
    26.785    55.267
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.769    55.274
    26.785    55.267
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.861    55.284
    26.861    55.283
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.841    55.269
    26.861    55.283
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.858    55.266
    26.858    55.266
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.845    55.290
    26.858    55.266
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.825    55.378
    26.824    55.378
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.779    55.378
    26.824    55.378
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.840    55.267
    26.840    55.267
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.062    55.211
    26.840    55.267
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.844    55.274
    26.844    55.274
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.868    55.304
    26.844    55.274
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.846    55.165
    26.848    55.164
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.827    55.096
    26.848    55.164
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.809    55.362
    26.809    55.362
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.771    55.359
    26.809    55.362
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.801    55.293
    26.801    55.293
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.762    55.287
    26.801    55.293
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.809    55.359
    26.809    55.358
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.831    55.408
    26.809    55.358
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.823    55.326
    26.824    55.326
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.831    55.351
    26.824    55.326
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.824    55.172
    26.824    55.172
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.804    55.151
    26.824    55.172
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.833    55.295
    26.833    55.295
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.818    55.305
    26.833    55.295
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.842    55.288
    26.842    55.288
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.791    55.266
    26.842    55.288
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.783    55.368
    26.784    55.369
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.904    55.505
    26.784    55.369
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.806    55.273
    26.806    55.273
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.798    55.226
    26.806    55.273
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.856    55.336
    26.857    55.336
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.823    55.282
    26.857    55.336
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.833    55.325
    26.833    55.324
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.794    55.331
    26.833    55.324
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.799    55.314
    26.799    55.314
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.782    55.348
    26.799    55.314
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.813    55.389
    26.813    55.389
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.766    55.321
    26.813    55.389
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.778    55.358
    26.778    55.358
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.725    55.312
    26.778    55.358
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.797    55.301
    26.798    55.301
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.804    55.287
    26.798    55.301
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.911    55.447
    26.911    55.443
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.880    55.403
    26.911    55.443
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.808    55.387
    26.807    55.386
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.775    55.291
    26.807    55.386
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.867    55.365
    26.867    55.365
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.839    55.338
    26.867    55.365
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.857    55.211
    26.856    55.209
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.819    55.193
    26.856    55.209
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.743    55.284
    26.743    55.285
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.716    55.289
    26.743    55.285
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.797    55.328
    26.797    55.328
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.759    55.321
    26.797    55.328
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.875    55.425
    26.875    55.425
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.854    55.402
    26.875    55.425
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.792    55.256
    26.792    55.256
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.709    55.257
    26.792    55.256
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.809    55.307
    26.809    55.307
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.755    55.282
    26.809    55.307
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.794    55.322
    26.794    55.321
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.688    55.274
    26.794    55.321
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.800    55.279
    26.800    55.279
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.787    55.304
    26.800    55.279
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.797    55.287
    26.797    55.286
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.800    55.260
    26.797    55.286
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.778    55.274
    26.778    55.274
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.733    55.230
    26.778    55.274
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.806    55.310
    26.806    55.309
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.737    55.285
    26.806    55.309
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.814    55.325
    26.814    55.324
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.798    55.327
    26.814    55.324
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.806    55.348
    26.806    55.348
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.795    55.341
    26.806    55.348
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.798    55.282
    26.798    55.282
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.754    55.266
    26.798    55.282
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.800    55.290
    26.801    55.289
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.712    55.278
    26.801    55.289
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.829    55.333
    26.830    55.333
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.838    55.311
    26.830    55.333
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.844    55.427
    26.844    55.428
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.860    55.430
    26.844    55.428
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.861    55.357
    26.861    55.356
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.821    55.326
    26.861    55.356
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.850    55.392
    26.850    55.392
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.754    55.334
    26.850    55.392
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.851    55.355
    26.851    55.355
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.863    55.385
    26.851    55.355
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.822    55.313
    26.822    55.313
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.738    55.245
    26.822    55.313
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.892    55.378
    26.892    55.378
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.901    55.292
    26.892    55.378
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.871    55.363
    26.871    55.363
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.850    55.348
    26.871    55.363
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.829    55.333
    26.829    55.333
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.791    55.297
    26.829    55.333
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.806    55.282
    26.806    55.282
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.737    55.257
    26.806    55.282
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.856    55.401
    26.856    55.400
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.789    55.360
    26.856    55.400
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.806    55.316
    26.806    55.316
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.763    55.278
    26.806    55.316
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.790    55.252
    26.790    55.251
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.812    55.246
    26.790    55.251
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.832    55.353
    26.832    55.352
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.963    55.355
    26.832    55.352
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.864    55.246
    26.864    55.246
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.958    55.337
    26.864    55.246
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.844    55.334
    26.844    55.334
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.815    55.300
    26.844    55.334
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.830    55.377
    26.830    55.377
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.702    55.292
    26.830    55.377
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.801    55.303
    26.801    55.303
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.917    55.349
    26.801    55.303
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.820    55.355
    26.820    55.354
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.822    55.401
    26.820    55.354
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.858    55.421
    26.859    55.421
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.846    55.403
    26.859    55.421
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.789    55.280
    26.789    55.280
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.769    55.273
    26.789    55.280
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.832    55.332
    26.831    55.331
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.782    55.355
    26.831    55.331
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.828    55.163
    26.828    55.163
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.774    55.118
    26.828    55.163
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.812    55.316
    26.812    55.316
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.886    55.381
    26.812    55.316
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.829    55.341
    26.828    55.342
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.767    55.313
    26.828    55.342
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.795    55.278
    26.795    55.278
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.647    55.231
    26.795    55.278
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.820    55.445
    26.820    55.445
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.799    55.443
    26.820    55.445
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.210    55.480
    27.210    55.480
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.265    55.519
    27.210    55.480
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.853    55.245
    26.853    55.244
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.833    55.212
    26.853    55.244
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.395    56.065
    27.395    56.065
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.265    56.235
    27.395    56.065
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.819    55.310
    26.819    55.310
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.788    55.335
    26.819    55.310
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.845    55.401
    26.845    55.401
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.195    55.525
    26.845    55.401
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.851    55.315
    26.852    55.315
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.854    55.289
    26.852    55.315
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.823    55.365
    26.824    55.365
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.808    55.183
    26.824    55.365
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.791    55.231
    26.792    55.231
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.502    55.204
    26.792    55.231
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.826    55.369
    26.826    55.368
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.826    55.327
    26.826    55.368
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.779    55.326
    26.779    55.326
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.825    55.364
    26.779    55.326
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.837    55.283
    26.837    55.283
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.774    55.231
    26.837    55.283
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.829    55.331
    26.829    55.331
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.869    55.185
    26.829    55.331
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.842    55.371
    26.842    55.371
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.035    55.569
    26.842    55.371
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.717    55.184
    26.717    55.183
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.739    55.103
    26.717    55.183
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.828    55.300
    26.828    55.300
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.828    55.204
    26.828    55.300
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.844    55.320
    26.844    55.320
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.750    55.276
    26.844    55.320
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.737    55.056
    26.737    55.055
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.749    55.016
    26.737    55.055
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.868    55.379
    26.868    55.379
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.198    55.486
    26.868    55.379
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.861    55.292
    26.861    55.291
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.833    55.157
    26.861    55.291
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.815    55.330
    26.815    55.330
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.804    55.281
    26.815    55.330
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.795    55.382
    26.796    55.382
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.814    55.410
    26.796    55.382
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.751    55.401
    27.752    55.401
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.800    55.380
    27.752    55.401
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.742    55.379
    27.742    55.378
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.753    55.285
    27.742    55.378
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.802    55.288
    26.801    55.288
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.674    55.273
    26.801    55.288
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.231    55.189
    27.231    55.188
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.265    55.097
    27.231    55.188
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.824    55.249
    26.824    55.248
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.861    55.150
    26.824    55.248
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.855    55.257
    26.855    55.257
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.850    55.355
    26.855    55.257
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.748    55.070
    26.748    55.070
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.707    55.070
    26.748    55.070
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.925    56.088
    26.925    56.088
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.921    55.947
    26.925    56.088
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    27.149    55.785
    27.150    55.785
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    27.031    55.732
    27.150    55.785
END
gmt psxy -: -R $projection -Wthin,green -O -K << END >> $psfile
    26.829    55.427
    26.828    55.428
END
gmt psxy -: -R $projection -Wthin,black -O -K << END >> $psfile
    26.909    55.435
    26.828    55.428
END

# Confidence ellipses for relative location
gmt psxy -: -R $projection -SE -Wthick -O -K << END >> $psfile
    27.024    55.532   -70.101     1.813     2.456
    27.046    55.608     2.652     3.778     4.066
    27.066    55.573   -74.481     3.074     3.644
    27.034    55.540   -29.689     5.015     5.296
    27.315    55.032   -61.636     2.353     3.871
    27.057    55.488   -66.572     2.912     3.900
    27.111    55.350   -69.893     2.305     3.015
    27.109    55.372   -58.075     2.998     4.154
    27.072    55.482   -86.097     4.239     6.596
    27.842    54.950   -62.029     1.878     3.091
    27.301    54.971    82.650     4.821     8.839
    27.386    56.144   -69.002     2.200     3.961
    27.131    55.423    81.154     3.645     6.611
    27.120    55.441    84.180     3.177     5.355
    27.160    55.948    87.590     2.259     4.657
    26.875    55.787   -85.628     2.761     4.575
    26.733    54.981   -83.401     2.087     3.994
    26.705    54.909   -78.110     2.543     5.138
    26.975    56.222   -84.781     2.909     5.109
    26.770    55.049   -79.857     2.266     4.051
    27.430    56.197   -82.247     1.597     2.545
    26.796    55.981   -84.468     2.471     4.404
    27.374    55.850   -81.348     1.452     2.626
    27.315    54.983   -88.576     2.591     5.342
    26.968    54.910   -78.645     2.648     6.496
    27.388    56.174   -73.304     3.162     4.560
    26.930    54.882    84.289     2.519     6.026
    27.053    55.641   -78.895     2.379     5.146
    26.659    55.897    71.963     3.814     8.754
    27.414    56.208    78.774     4.562     4.716
    27.292    56.111   -58.734     2.736     3.585
    27.082    56.079   -16.331     2.300     3.365
    26.837    55.896   -76.286     0.983     1.259
    26.851    55.873    16.539     6.116     8.743
    26.797    55.865   -75.872     1.415     1.843
    26.825    55.894   -12.702     2.307     2.622
    26.804    55.931    42.086     5.384     8.829
    26.847    55.859    -5.586     2.399     3.296
    26.895    55.839   -82.154     1.326     1.960
    26.830    55.898    -5.726     3.491     4.111
    26.816    55.887   -10.703     3.026     4.150
    26.835    55.904   -17.052     3.188     5.045
    26.814    55.867   -20.151     2.251     4.132
    26.809    55.903   -71.861     2.123     3.247
    26.836    55.791    -3.029     2.458     3.218
    26.809    55.903    32.801     2.030     2.429
    26.798    55.900   -14.234     2.618     4.528
    26.861    55.982    87.745     0.900     1.053
    26.823    55.885   -60.169     1.251     1.735
    26.901    55.917    51.163     1.611     1.874
    26.852    55.959    68.669     1.507     1.901
    26.823    55.918    68.842     1.521     2.182
    26.864    55.963    60.570     1.100     1.387
    26.898    55.933    59.481     1.050     1.240
    26.847    55.970    65.572     0.898     1.077
    26.837    55.976    69.073     1.388     1.710
    26.864    55.964   -19.247     1.651     1.757
    26.874    55.951    53.290     1.780     2.009
    26.820    55.965    69.672     1.527     2.036
    26.838    55.942    87.168     1.928     2.523
    26.819    55.940    65.927     0.753     0.904
    26.822    55.909    71.718     0.958     1.098
    26.833    55.852   -42.035     1.377     1.591
    26.853    55.929    56.173     1.023     1.327
    26.823    55.887    75.487     1.188     1.539
    26.851    55.961    61.580     0.970     1.147
    26.821    55.960    63.605     1.039     1.302
    27.341    54.959   -32.502     4.322     6.493
    26.886    55.920    60.814     0.971     1.029
    26.820    55.898    67.820     1.043     1.367
    26.908    55.741   -18.265     2.743     3.644
    27.503    55.492   -37.006     2.639     3.637
    27.480    55.385   -25.238     3.699     5.905
    26.824    55.941   -57.126     2.013     2.206
    26.825    55.889   -49.183     2.310     2.941
    27.745    55.403   -35.938     4.101     7.051
    27.736    55.433   -25.553     3.415     6.622
    27.372    54.946   -50.033     2.829     4.006
    26.826    55.944   -66.719     1.322     1.924
    26.831    55.935   -34.159     2.262     2.786
    26.850    55.969   -18.072     3.058     6.673
    26.894    55.967    54.826     4.260     5.307
    26.911    55.889   -68.162     1.038     1.323
    26.932    55.877   -36.184     2.440     2.878
    26.945    55.941     1.047     1.894     2.491
    26.899    55.892   -11.139     2.069     3.654
    26.874    55.871    -9.425     2.733     4.387
    26.844    55.922   -11.420     2.539     4.160
    26.910    55.938   -32.053     1.754     2.199
    26.928    55.898   -16.202     1.589     3.019
    26.933    55.919   -21.838     2.115     2.723
    26.973    55.923    -8.249     2.539     3.691
    26.893    55.892    -6.387     2.735     4.422
    26.917    55.939    -8.001     2.211     3.837
    26.941    55.935    -5.109     2.925     4.508
    26.871    55.886   -12.717     2.234     3.578
    26.868    55.843    -6.854     3.444     4.556
    26.850    55.906   -17.172     1.875     2.933
    27.587    55.294   -38.410     2.616     3.997
    27.731    55.158   -43.952     2.496     3.132
    26.934    55.926   -13.857     2.209     3.670
    27.603    55.289   -63.704     3.056     3.223
    26.890    55.914    -8.679     2.397     4.223
    26.901    55.941    -8.475     2.346     3.799
    26.918    55.905    -3.556     2.755     3.894
    26.780    55.830   -21.945     3.065     5.357
    27.605    55.262   -71.466     3.300     4.355
    27.014    54.971   -49.661     1.624     2.421
    27.604    55.406   -61.423     3.540     4.399
    27.615    55.450   -70.084     2.079     3.152
    26.877    56.335     1.864     2.289     3.369
    26.842    55.340    66.400     2.453     2.663
    26.875    56.291    -5.416     2.843     5.728
    27.417    56.006    -1.426     3.479     4.424
    27.374    55.986    85.704     3.610     5.616
    27.749    55.041   -65.851     3.869     7.190
    27.343    55.981    84.745     3.407     4.472
    27.814    55.236   -74.778     5.032     6.081
    26.860    55.898   -64.477     0.950     1.167
    26.851    55.892    71.372     3.934     4.970
    26.886    55.896    -4.009     4.132     5.850
    26.908    55.867    -0.313     4.651     5.305
    26.852    55.898   -59.504     1.749     1.882
    26.947    55.858    60.003     5.379    10.740
    26.912    55.936     6.776     3.414     4.834
    26.856    55.845     0.650     2.973     5.211
    26.851    55.876    -6.630     2.156     2.916
    26.872    55.946    58.139     4.136     5.767
    26.904    55.925   -85.453     4.293     5.512
    26.868    55.855    -5.598     1.729     1.866
    26.875    55.859   -66.501     1.276     1.619
    26.865    55.854    -8.244     4.162     4.822
    26.867    55.899    44.841     1.999     2.929
    26.946    56.079   -84.159     1.407     1.619
    26.975    56.127    47.275     4.295     6.307
    26.991    56.116    17.733     2.677     2.945
    26.993    56.104    53.755     6.096     7.631
    26.982    56.084    45.055     2.558     6.557
    27.004    56.112    43.887     4.402     5.990
    26.885    56.173    40.121     3.277    10.179
    26.978    56.070   -17.943     2.152     2.618
    26.944    55.863    -2.556     2.846     3.766
    26.936    56.016    19.334     2.286     3.490
    26.957    56.175    11.545     3.487     5.210
    26.899    55.915    -2.350     2.826     4.254
    27.381    56.026    49.758     3.592     6.495
    26.972    56.168    16.579     3.096     4.292
    26.970    56.102     8.049     2.711     3.303
    26.982    56.143    25.058     2.414     4.302
    26.971    56.124    29.581     2.329     3.936
    26.968    56.134    -4.217     3.229     5.622
    26.954    56.120     4.556     2.061     3.501
    27.435    56.161   -14.141     3.321     4.945
    26.808    55.896    -3.628     2.626     4.220
    26.679    55.126   -26.443     2.670     3.176
    26.919    55.943     3.140     2.533     4.079
    26.779    55.037    89.899     4.646     9.311
    26.701    55.042    73.586     3.244     5.205
    26.725    55.086   -86.790     1.901     3.508
    26.678    55.121   -22.156     3.382     5.189
    26.853    55.863    10.417     2.650     3.412
    26.621    55.061   -45.284     2.106     2.723
    26.897    55.918    76.773     1.962     2.031
    26.961    55.941   -71.904     1.109     1.465
    26.958    55.925    -1.872     3.224     4.654
    26.961    55.948   -59.756     1.240     1.470
    26.942    55.930   -13.320     1.410     1.693
    27.006    55.931    12.118     5.417     7.248
    26.878    55.905    41.456     2.433     4.271
    26.960    56.045     1.368     2.264     4.196
    26.927    56.003    -6.742     2.319     4.511
    27.589    55.498   -57.236     1.649     2.267
    27.160    55.851    -7.544     2.486     4.273
    26.929    55.935    -4.420     2.639     4.940
    26.814    55.827   -62.108     0.962     1.357
    26.801    55.806     8.239     3.061     5.088
    26.791    55.855    -8.550     1.765     2.865
    26.794    55.849    -8.686     2.349     4.291
    27.196    56.116    -8.969     3.223     4.459
    27.247    56.222   -72.367     1.708     1.977
    27.231    56.266    -0.460     3.167     5.436
    26.957    56.059   -21.958     2.014     2.222
    27.609    55.239   -64.401     1.813     2.387
    27.187    55.604    -4.088     2.740     3.791
    27.198    55.609   -53.888     2.188     2.790
    27.221    55.018   -68.609     1.469     2.396
    27.212    54.949   -24.954     2.895     4.229
    27.188    54.921   -18.570     2.228     2.902
    27.406    56.170   -11.067     2.748     5.194
    26.952    55.712   -13.120     3.017     3.962
    27.064    55.666   -33.452     2.597     3.356
    27.519    55.356   -57.488     1.578     2.280
    27.334    55.977     5.403     2.547     5.556
    26.873    55.944     3.061     2.168     5.868
    27.318    56.478   -17.074     2.218     3.322
    27.378    55.669   -36.640     2.020     3.003
    26.677    55.453    -9.295     2.895     3.635
    27.751    55.017   -25.013     3.270     5.908
    26.691    55.342   -21.181     2.764     5.024
    26.899    55.862    -6.153     2.516     5.023
    26.690    55.098   -29.917     2.445     4.776
    27.095    55.709   -45.654     1.016     1.242
    27.176    54.830   -38.960     1.406     2.002
    27.153    54.884   -21.858     2.360     2.950
    26.975    55.109   -26.594     2.740     5.014
    27.277    55.646    -6.090     2.395     3.952
    27.103    56.267   -13.241     1.631     3.056
    26.912    56.119   -20.413     2.292     3.078
    27.031    55.080   -13.771     2.519     5.563
    27.039    56.220    -2.554     1.536     2.796
    26.789    55.269   -14.310     1.503     3.124
    27.310    55.020   -48.009     1.183     1.728
    27.254    55.017   -30.720     1.661     2.976
    27.311    54.994   -30.983     3.254     4.390
    27.326    55.006   -13.228     2.770     5.365
    27.238    55.003   -22.676     2.327     3.628
    27.317    55.019   -16.172     1.733     3.247
    27.322    55.020   -27.085     1.654     2.701
    26.927    54.959   -14.022     2.817     5.440
    27.250    55.876   -26.869     1.140     1.345
    26.952    54.913   -24.082     1.607     3.274
    26.739    55.096   -21.204     2.005     4.374
    26.581    55.859   -36.447     1.397     1.710
    26.890    55.400   -14.776     1.823     3.810
    26.916    55.964    -5.887     1.806     6.048
    26.898    54.895   -16.137     2.530     4.969
    26.861    55.932    -6.099     1.505     3.358
    26.853    55.945    -1.925     1.846     4.164
    27.318    54.867   -22.851     1.609     2.589
    27.213    55.184   -27.178     1.143     1.681
    26.566    55.318   -21.946     2.199     5.882
    27.289    55.766   -11.274     1.712     4.179
    27.246    55.961     1.458     1.834     4.093
    27.243    54.973   -18.764     2.053     4.909
    27.226    55.022   -16.379     1.944     4.177
    26.788    54.898   -19.028     1.810     2.826
    26.806    54.924   -22.094     2.151     3.982
    26.571    55.869     2.107     1.699     2.935
    27.735    55.053   -28.910     2.272     2.859
    27.015    55.164    -6.028     2.760     5.300
    27.162    55.116   -21.106     2.325     4.265
    27.177    55.138    -3.472     1.887     2.933
    26.548    55.222   -23.409     1.636     2.691
    26.640    55.471   -18.224     1.509     2.307
    26.517    55.048   -11.082     2.511     4.730
    27.308    54.907   -32.936     1.185     1.691
    27.203    55.141    -9.618     1.800     3.266
    26.987    54.940   -20.695     1.778     3.228
    26.967    54.926   -25.489     2.290     3.961
    26.517    55.850    -3.995     2.439     5.245
    26.509    55.763     4.410     2.903     5.300
    27.095    56.069     1.528     1.927     5.946
    26.478    55.671    -3.503     2.131     4.903
    26.464    55.713    -2.988     3.152     6.197
    27.110    56.060    -0.916     2.167     5.120
    26.940    54.897   -24.000     1.603     2.674
    26.646    55.512   -12.226     2.370     4.115
    26.842    55.384    -9.004     2.421     3.564
    27.345    56.145    -0.794     1.814     3.531
    27.358    54.915   -12.177     2.697     5.459
    27.739    55.192   -11.097     2.241     3.942
    27.620    55.382    -8.255     1.987     4.362
    26.868    55.982    -1.855     1.531     3.503
    26.985    54.873   -18.039     1.873     3.841
    26.931    55.972     0.707     2.404     6.178
    26.608    55.718    -4.974     2.017     4.238
    27.406    56.194    -0.119     1.728     3.401
    26.817    55.226    -4.293     2.931     4.298
    26.545    56.419    14.021     2.835     5.877
    27.397    56.399     1.786     2.844     4.335
    26.719    55.619   -11.049     2.609     5.428
    26.922    55.905    -8.082     1.326     2.333
    27.046    55.154   -10.185     2.822     4.878
    27.145    56.008     2.475     2.106     4.949
    27.597    54.962   -51.244     1.481     1.973
    27.623    54.944   -66.313     0.935     1.237
    27.598    54.983   -16.315     2.052     3.076
    27.594    55.006   -14.062     1.839     2.908
    27.614    54.954   -53.681     1.030     1.092
    27.622    54.986   -14.003     2.318     3.360
    27.078    55.142   -14.513     2.248     3.754
    27.613    54.996   -11.860     1.810     2.714
    27.224    56.256     2.031     2.060     4.281
    27.706    54.945   -14.168     2.088     2.946
    27.392    56.274     0.364     1.561     2.855
    26.906    55.817    -4.927     1.899     3.182
    27.170    55.852     0.898     1.577     2.762
    27.046    55.692   -34.422     1.085     1.332
    27.037    55.679    -4.862     1.560     3.161
    26.972    55.712    -2.872     2.500     4.571
    27.043    55.688   -10.655     1.388     2.204
    27.013    55.143    -7.856     2.339     4.123
    27.082    55.275   -13.800     1.464     2.681
    27.150    55.879     3.550     0.989     1.199
    26.839    55.358   -15.168     1.381     2.530
    27.031    55.680    -9.350     1.510     2.893
    26.864    55.376    -7.768     1.720     2.268
    27.180    54.896    -7.024     2.480     3.604
    26.710    55.150   -37.890     1.328     1.728
    26.710    55.102    -8.168     1.581     3.379
    26.728    55.122   -29.131     2.551     3.321
    26.691    55.128   -12.466     2.877     4.553
    26.596    55.474   -15.037     1.627     2.876
    26.695    56.260     4.998     2.073     4.994
    26.927    55.703   -15.058     1.177     1.935
    26.940    55.697    -8.385     1.684     3.164
    26.929    55.697    -8.223     1.502     2.643
    26.936    55.689    -4.223     2.042     4.038
    27.214    54.850    -4.364     2.510     3.711
    26.675    55.287   -18.847     1.519     2.458
    26.658    55.269   -15.834     2.117     3.465
    27.199    55.153   -48.300     0.985     1.313
    27.192    55.089    -5.829     1.992     3.332
    27.232    55.071   -14.220     1.354     2.108
    27.189    55.106   -17.816     1.790     2.920
    27.221    55.071   -25.043     1.986     2.875
    27.222    55.069   -14.710     1.476     2.571
    27.196    55.106   -19.193     1.640     2.698
    27.195    55.113    -2.498     1.699     2.951
    27.180    55.141    -7.468     1.544     2.581
    27.209    55.088   -19.373     1.406     1.995
    26.665    55.261    -8.465     2.684     4.543
    27.179    55.096    -8.711     2.632     4.635
    27.201    55.082    -7.177     1.730     2.829
    27.185    55.087   -20.890     1.330     1.964
    27.233    55.140   -19.191     1.678     2.700
    27.167    55.069    -9.646     2.981     4.526
    27.250    55.113   -45.597     1.288     1.578
    27.254    55.065   -11.100     2.124     3.077
    27.254    55.064    -8.042     2.673     4.218
    27.263    55.026   -13.973     1.412     2.056
    27.267    55.040   -26.458     1.329     1.921
    27.261    55.034    -2.153     2.051     3.123
    27.216    55.060    -9.108     1.823     3.079
    27.227    55.108   -17.115     1.375     1.969
    27.279    55.017   -14.639     2.142     3.068
    27.236    54.977    -5.618     2.617     3.557
    27.196    55.104   -15.617     1.315     2.013
    27.166    56.000     0.142     1.762     3.169
    26.708    55.096   -17.433     2.140     3.130
    26.642    55.465   -21.628     1.672     3.044
    27.053    55.917    -8.810     1.620     3.484
    27.053    55.876    -9.749     1.690     3.236
    27.052    55.889   -10.183     1.466     2.500
    27.055    55.885   -21.297     1.421     1.742
    27.051    55.848   -62.612     0.822     0.954
    27.057    55.923    -1.407     1.607     3.473
    27.164    54.850   -12.784     1.435     2.205
    27.189    55.115    -8.617     1.855     2.688
    27.317    54.915   -14.591     2.252     3.930
    26.836    55.823   -17.941     1.303     2.258
    27.118    56.221     2.191     1.985     3.866
    26.605    55.588   -18.241     1.718     2.877
    27.358    55.402   -51.845     0.889     1.152
    26.747    55.963    -1.981     1.871     3.892
    27.338    55.431    -6.325     2.703     5.598
    26.700    56.406     8.556     3.480     7.396
    26.964    56.165     2.480     2.782     7.174
    26.949    56.132     1.845     1.698     2.782
    27.362    55.415   -32.380     1.416     2.318
    27.190    55.125    -8.597     2.429     4.844
    26.853    55.350   -50.629     1.082     1.405
    26.859    55.266    22.007     4.266     5.759
    26.792    55.279   -22.560     1.235     1.993
    26.849    55.281   -28.545     1.075     1.608
    26.848    55.285    -8.283     1.488     3.637
    26.912    55.486    12.118     4.377     6.574
    26.796    55.262     2.221     3.244     6.391
    26.822    55.325   -16.541     1.815     3.214
    26.846    55.267   -11.568     2.785     6.137
    26.848    55.341   -18.059     1.388     2.521
    26.904    55.557    -3.866     1.755     3.828
    26.780    55.168    -9.277     2.601     5.300
    27.361    56.147     3.018     2.160     3.847
    26.649    55.518   -10.578     1.829     3.281
    26.950    55.729     8.493     2.251     4.387
    26.827    55.318   -11.439     1.402     2.574
    26.969    55.010   -16.051     2.278     4.866
    27.404    55.318   -22.914     1.217     1.883
    27.406    55.298    -0.721     2.590     6.081
    26.817    55.168   -13.468     1.636     2.866
    27.266    55.637   -18.271     1.864     3.097
    27.290    55.573   -12.447     2.437     4.626
    27.299    55.645    -7.936     2.496     6.226
    27.278    55.590    -7.952     2.110     3.695
    26.842    55.283   -55.767     2.562     3.510
    26.828    55.226   -23.454     2.247     4.491
    26.820    55.337   -12.243     1.742     2.634
    26.845    55.343   -24.319     1.502     2.404
    26.809    55.375   -21.106     1.279     1.975
    26.851    55.296   -30.824     1.862     3.351
    26.799    55.348   -71.072     1.882     2.536
    26.811    55.279   -26.609     1.966     3.903
    26.854    55.367   -10.294     2.538     4.709
    26.801    55.318   -20.188     1.706     2.960
    26.765    55.697   -21.323     2.683     5.096
    26.837    55.261   -17.846     1.696     3.849
    26.835    55.384   -11.919     2.295     5.256
    26.861    55.355   -11.814     2.131     4.304
    26.853    55.363   -21.766     1.631     2.742
    26.850    55.153   -22.399     1.562     2.373
    26.834    55.211   -14.609     2.444     5.075
    26.785    55.267   -15.560     1.410     2.270
    26.861    55.283   -28.563     1.280     2.019
    26.858    55.266    -6.348     1.697     3.256
    26.824    55.378   -11.757     2.280     4.152
    26.840    55.267    -8.179     2.084     3.581
    26.844    55.274   -12.307     1.818     3.209
    26.848    55.164   -25.578     1.512     2.356
    26.809    55.362    -6.716     2.270     3.906
    26.801    55.293    -9.944     1.714     3.092
    26.809    55.358    -9.062     2.529     4.260
    26.824    55.326   -13.821     2.123     4.791
    26.824    55.172   -16.471     1.389     2.247
    26.833    55.295   -16.117     1.538     2.823
    26.842    55.288   -28.753     1.399     2.646
    26.784    55.369    -6.818     1.627     2.769
    26.806    55.273   -28.219     1.718     3.323
    26.857    55.336   -19.978     1.761     3.115
    26.833    55.324   -13.992     1.804     3.261
    26.799    55.314   -17.331     2.179     3.932
    26.813    55.389   -19.898     1.861     3.125
    26.778    55.358   -15.496     1.670     3.327
    26.798    55.301   -22.846     1.337     2.244
    26.911    55.443   -12.281     1.763     3.725
    26.807    55.386   -12.532     2.263     4.007
    26.867    55.365   -12.195     1.600     2.783
    26.856    55.209   -15.424     2.777     4.583
    26.743    55.285   -13.564     1.747     3.006
    26.797    55.328    -9.758     1.821     3.088
    26.875    55.425    -7.082     1.998     2.846
    26.792    55.256   -19.965     1.625     2.585
    26.809    55.307   -19.849     1.796     3.009
    26.794    55.321   -12.606     2.588     3.654
    26.800    55.279   -11.839     2.324     3.409
    26.797    55.286   -24.948     1.785     2.594
    26.778    55.274   -15.709     1.650     2.575
    26.806    55.309   -14.517     2.043     3.396
    26.814    55.324   -20.207     1.830     2.781
    26.806    55.348    -7.840     1.967     3.289
    26.798    55.282    -9.919     1.306     2.162
    26.801    55.289   -19.329     1.393     2.139
    26.830    55.333   -49.812     0.954     1.275
    26.844    55.428   -64.824     1.460     2.261
    26.861    55.356    -9.664     1.689     2.926
    26.850    55.392   -10.815     1.432     2.814
    26.851    55.355   -18.101     1.686     3.293
    26.822    55.313   -11.830     1.470     2.597
    26.892    55.378   -19.519     1.538     2.468
    26.871    55.363   -19.139     1.734     2.785
    26.829    55.333   -16.955     2.102     3.107
    26.806    55.282   -19.223     1.659     2.499
    26.856    55.400   -15.480     1.483     2.418
    26.806    55.316   -15.681     1.900     3.828
    26.790    55.251    -0.890     2.645     3.230
    26.832    55.352   -17.748     2.237     4.161
    26.864    55.246   -15.758     1.991     3.384
    26.844    55.334   -15.000     1.695     2.876
    26.830    55.377   -17.282     1.752     3.531
    26.801    55.303   -16.467     2.369     4.044
    26.820    55.354    -4.891     1.733     3.016
    26.859    55.421    -9.257     2.213     3.300
    26.789    55.280    -9.921     1.749     2.649
    26.831    55.331   -12.750     1.919     3.654
    26.828    55.163   -13.950     2.092     3.998
    26.812    55.316   -11.541     2.439     3.838
    26.828    55.342    -5.488     2.448     3.308
    26.795    55.278   -17.710     2.682     3.847
    26.820    55.445   -17.336     1.355     2.478
    27.210    55.480   -19.083     1.998     3.414
    26.853    55.244   -47.013     0.983     1.291
    27.395    56.065     4.567     2.881     5.778
    26.819    55.310   -14.648     1.558     2.514
    26.845    55.401   -19.855     2.253     3.000
    26.852    55.315   -50.798     0.806     1.111
    26.824    55.365   -19.752     1.422     2.491
    26.792    55.231   -30.235     2.555     4.559
    26.826    55.368   -11.873     1.786     3.154
    26.779    55.326   -10.527     1.944     3.064
    26.837    55.283   -10.434     2.026     3.399
    26.829    55.331   -22.722     1.451     2.369
    26.842    55.371   -13.572     1.604     2.775
    26.717    55.183   -18.935     1.260     2.032
    26.828    55.300   -12.598     1.573     2.780
    26.844    55.320    -7.114     1.617     3.526
    26.737    55.055   -21.278     1.504     2.632
    26.868    55.379    -4.801     2.238     4.872
    26.861    55.291   -24.686     1.619     2.965
    26.815    55.330   -24.508     2.323     4.865
    26.796    55.382   -27.212     1.975     3.459
    27.752    55.401   -35.445     1.023     1.433
    27.742    55.378   -37.463     1.036     1.483
    26.801    55.288   -25.279     1.921     3.125
    27.231    55.188   -24.350     1.497     3.543
    26.824    55.248   -21.922     1.552     3.015
    26.855    55.257   -40.787     1.943     3.600
    26.748    55.070   -30.566     1.610     2.861
    26.925    56.088    -0.742     1.936     3.760
    27.150    55.785   -15.476     1.757     3.251
    26.828    55.428   -25.140     2.100     3.405
END

# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
    26.860    55.898     0.200
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
    26.842    55.283     0.200
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
    26.799    55.348     0.200
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# User-defined stars
gmt psxy -: -R $projection -Sa -Wthicker,red -Gred -O -K << END >> $psfile
END


# Hypocentroid confidence ellipse
gmt psxy -: -R $projection -SE -Wthick,blue -O -K << END >> $psfile
    26.418    54.791    15.501     0.885     1.288
END
gmt pstext -: -R $projection -F+f6p,Helvetica,blue+a0.+jBL -O -K << END >> $psfile
    26.418    54.813   Hypocentroid
END

# Circle of radius 5 km for reference
gmt psxy -: -R $projection -SE -Wthick,red -O -K << END >> $psfile
    26.418    54.791     0.000    10.000    10.000
END
gmt psxy -: -R $projection -Sx -Wthinnest,blue -O -K << END >> $psfile
    26.418    54.791     0.070
END
gmt pstext -: -R $projection -F+f6p,Helvetica-Bold,red+a0.+jBC -Gwhite -O << END >> $psfile
    26.373    54.791   5 km
END
